%% Set up environment %%
clear
rng(1)

%% Externally calibrated parameters and grids %%
global r R alpha zGrid0

% Externally calibrated parameters
r = log(1.05); % real borrowing rate
R = r-log(1-0.148); % user cost of capital
alpha = R*1.1; % capital share of net value added

% Grids
Nz0=500;
zGrid0 = real(getGrid(1,1/2,10,Nz0,2,1)); % affine-exponential
NzPareto0=500;
zGridPareto0 = real(getGrid(1,1/2,1e2,NzPareto0,2,2)); % affine-exponential

%% Calibration - Baseline model %%
lb = [0.15 0.1 0.1 1.5 0.5 0];
ub = [0.3 0.4 0.4 4 3 0.15] ; 
aMatIneq = [1 -1 0 0 0 -1 ; 1 0 -1 0 0 -1 ]; 
bConsIneq = -1e-2*ones(2,1);
loss = @(paramEval) getLoss(zGrid0,Nz0,paramEval(1),paramEval(2),paramEval(3),paramEval(4),paramEval(5),paramEval(6),0,1);
param = fmincon(loss,[0.25 0.25 0.25 2.5 0.25 0.025],aMatIneq,bConsIneq,[],[],lb,ub);

[zbar wbar zGrid vGrid wGrid] = getEQ(zGrid0,Nz0,param(1),param(2),param(3),param(4),param(5),param(6),1);
[lsAgg lsAvg opCov u JDC JDD JCC JCB JC JD JR JRC JRBD rho lp9590 lp9050 lp5010 lp9010] = getModelOutputAgg(param(1),param(2),param(3),param(4),param(5),param(6),zbar,zGrid,vGrid,wGrid,1);
lossExp = @(paramEval) getLossExp(zGrid0,Nz0,param(1),param(2),param(3),paramEval,param(5),param(6),0,1);
lossExp2 = @(paramEval) getLossExp2(zGrid0,Nz0,param(1),param(2),param(3),paramEval(1),paramEval(2),param(6),u,0,1);

paramExpParam = fmincon(lossExp,param(4),[],[],[],[],2,4);
paramExp = [param(1:3) paramExpParam param(5:6) ];
paramExp2Param = fmincon(lossExp2,paramExp(4:5),[],[],[],[],lb(4:5),ub(4:5));
paramExp2 = [param(1:3) paramExp2Param param(6) ];

%% Calibration - Benchmark models %%
[zbar wbar zGrid vGrid wGrid] = getEQ(zGrid0,Nz0,param(1),param(2),param(3),param(4),param(5),param(6),1);
Gamma0zbar = getGammacdf(zbar,param(4),0,1);
lossExp = @(etaExpCmBm) getlp9010(zGrid0,Nz0,Gamma0zbar,param(1),param(2),param(3),etaExpCmBm,param(5),param(6),1)-(1.5468+0.23);
etaExpCmBm = fzero(lossExp,[1.5 4]);

%% Calibration - Pareto model %%
lb = [0.19 0.1 0.1 0 0];
ub = [0.5 0.4 0.4 3 0.05] ; 
aMatIneq = [1 -1 0 0 -1 ; 1 0 -1 0 -1 ]; 
bConsIneq = -1e-2*ones(2,1);
loss = @(paramEval) getLoss(zGridPareto0,NzPareto0,paramEval(1),paramEval(2),paramEval(3),log(9)/((1-alpha)*1.5468),paramEval(4),paramEval(5),0,2);
lossExp = @(paramEval) getLossExp(zGridPareto0,NzPareto0,paramEval(1),paramEval(2),paramEval(3),log(9)/((1-alpha)*(1.5468+0.23)),paramEval(4),paramEval(5),0,2);

paramParetoParam  = fmincon(loss,[param(1:3) param(4:5)],aMatIneq,bConsIneq,[],[],lb,ub);
paramPareto = [ paramParetoParam(1:3) log(9)/((1-alpha)*(1.5468)) paramParetoParam(4:5) ];
paramExpPareto = [ paramPareto(1:3) log(9)/((1-alpha)*(1.5468+0.23)) paramPareto(5:6) ];

[zbarPareto wbarPareto zGridPareto vGridPareto wGridPareto] = getEQ(zGridPareto0,NzPareto0,paramPareto(1),paramPareto(2),paramPareto(3),paramPareto(4),paramPareto(5),paramPareto(6),2);
[lsAggPareto lsAvgPareto opCovPareto uPareto JDCPareto JDDPareto JCCPareto JCBPareto JCPareto JDPareto JRPareto JRCPareto JRBDPareto rhoPareto lp9590Pareto lp9050Pareto lp5010Pareto lp9010Pareto] = getModelOutputAgg(paramPareto(1),paramPareto(2),paramPareto(3),paramPareto(4),paramPareto(5),paramPareto(6),zbarPareto,zGridPareto,vGridPareto,wGridPareto,2);

lossExp2 = @(paramEval) getLossExp2(zGridPareto0,NzPareto0,paramPareto(1),paramPareto(2),paramPareto(3),log(9)/((1-alpha)*(1.5468+0.23)),paramEval,paramPareto(6),uPareto,0,2);
bParetoExp2 = fmincon(lossExp2,paramExpPareto(5)+0.2,[],[],[],[],paramExpPareto(5),1.5*paramExpPareto(5));
paramExpPareto2 = [ paramPareto(1:3) log(9)/((1-alpha)*(1.5468+0.23)) bParetoExp2 paramPareto(6) ];

%% Calibration - Endogenous-lambda model %%
lb = [0.95*param(1:3) 0.9*param(4) 0.95*param(5:6)];
ub = [1.05*param(1:3) 1.1*param(4) 1.05*param(5:6)];

aMatIneq = [1 -1 0 0 0 -1 ; 1 0 -1 0 0 -1 ]; 
bConsIneq = -1e-2*ones(2,1);
DHFtarget = 0.82;

loss = @(paramEval) getLossEV(zGrid0,Nz0,paramEval(2),paramEval(3),paramEval(4),paramEval(5),paramEval(6),DHFtarget/(1-DHFtarget),paramEval(1),0,1);
paramEVParam = fmincon(loss,param(1:6),aMatIneq,bConsIneq,[],[],lb,ub);
paramEV = [paramEVParam DHFtarget/(1-DHFtarget)]

lossExp = @(paramEval) getLossEVexp(zGrid0,Nz0,paramEV(2),paramEV(3),paramEval,paramEV(5),paramEV(6),paramEV(7),paramEV(1),0,1);
paramEVexpParam = fmincon(lossExp,paramEV(4),[],[],[],[],1.5,4);
paramEVexp = [paramEV(1:3) paramEVexpParam paramEV(5:7)]

[lsAggEVexp lsAvgEVexp opCovEVexp uEVexp JDCEVexp JDDEVexp JCCEVexp JCBEVexp JCEVexp JDEVexp JREVexp JRCEVexp JRBDEVexp rhoEVexp lp9010EVexp passthroughOLSEVexp varlogwEVexp DHFslopeEVexp] = getEVModelOutput(zGrid0,Nz0,paramEV(2),paramEV(3),paramEV(4),paramEV(5),paramEV(6),paramEV(7),paramEV(1),1);
lossExp2 = @(paramEval) getLossEVexp2(zGrid0,Nz0,paramEV(2),paramEV(3),paramEval(1),paramEval(2),paramEV(6),paramEV(7),paramEV(1),uEVexp,0,1);
paramEVexp2Param = fmincon(lossExp2,[ paramEVexp(4) paramEVexp(5)],[],[],[],[],0.98*paramEVexp(4:5),1.02*paramEVexp(4:5));
paramEVexp2 = [paramEV(1:3) paramEVexp2Param paramEV(6:7)];

%% Validate calibration against what is reported in the paper %%
abs(param -           [0.2443    0.2311    0.3063    3.8773    0.5981    0.0233])<1e-4
abs(paramExp -        [0.2443    0.2311    0.3063    2.9974    0.5981    0.0233])<1e-4
abs(paramExp2 -       [0.2443    0.2311    0.3063    2.9943    0.5984    0.0233])<1e-4
abs(etaExpCmBm -      [2.9943])<1e-4
abs(paramPareto -     [0.2442    0.2311    0.3069    1.8445    1.1665    0.0233])<1e-4
abs(paramExpPareto -  [0.2442    0.2311    0.3069    1.6057    1.1665    0.0233])<1e-4
abs(paramExpPareto2 - [0.2442    0.2311    0.3069    1.6057    1.3563    0.0233])<1e-4
abs(paramEV -         [0.2390    0.2348    0.3080    3.6046    0.5788    0.0233    4.5556])<1e-4
abs(paramEVexp -      [0.2390    0.2348    0.3080    2.7573    0.5788    0.0233    4.5556])<1e-4
abs(paramEVexp2 -     [0.2390    0.2348    0.3080    2.7789    0.5788    0.0233    4.5556])<1e-4


