%% Externally calibrated parameters and grids %%
clear
global r R alpha zGrid0

% Grids
Nz0=500;
zGrid0 = real(getGrid(1,1/2,10,Nz0,2,1)); % affine-exponential
NzPareto0=500;
zGridPareto0 = real(getGrid(1,1/2,1e2,NzPareto0,2,2)); % affine-exponential

% Externally calibrated parameters
r = log(1.05); % real borrowing rate
R = r-log(1-0.148); % user cost of capital
alpha = R*1.1; % capital share of net value added

%% Calibration %%

param =           [0.2443    0.2311    0.3063    3.8773    0.5981    0.0233];
paramExp =        [0.2443    0.2311    0.3063    2.9974    0.5981    0.0233];
paramExp2 =       [0.2443    0.2311    0.3063    2.9943    0.5984    0.0233]; 
etaExpCmBm =      [2.9943];
paramPareto =     [0.2442    0.2311    0.3069    1.8445    1.1665    0.0233]; 
paramExpPareto =  [0.2442    0.2311    0.3069    1.6057    1.1665    0.0233]; 
paramExpPareto2 = [0.2442    0.2311    0.3069    1.6057    1.3563    0.0233];
paramEV =         [0.2390    0.2348    0.3080    3.6046    0.5788    0.0233    4.5556];
paramEVexp =      [0.2390    0.2348    0.3080    2.7573    0.5788    0.0233    4.5556];
paramEVexp2 =     [0.2390    0.2348    0.3080    2.7789    0.5788    0.0233    4.5556];

paramPerturb = [param*1.05 ; param*0.95 ];
momentPerturb1 = [ getLoss(zGrid0,Nz0,paramPerturb(1,1),param(2),param(3),param(4),param(5),param(6),1,1) - getLoss(zGrid0,Nz0,paramPerturb(2,1),param(2),param(3),param(4),param(5),param(6),1,1)];
momentPerturb2 = [ getLoss(zGrid0,Nz0,param(1),paramPerturb(1,2),param(3),param(4),param(5),param(6),1,1) - getLoss(zGrid0,Nz0,param(1),paramPerturb(2,2),param(3),param(4),param(5),param(6),1,1)];
momentPerturb3 = [ getLoss(zGrid0,Nz0,param(1),param(2),paramPerturb(1,3),param(4),param(5),param(6),1,1) - getLoss(zGrid0,Nz0,param(1),param(2),paramPerturb(2,3),param(4),param(5),param(6),1,1)];
momentPerturb4 = [ getLoss(zGrid0,Nz0,param(1),param(2),param(3),paramPerturb(1,4),param(5),param(6),1,1) - getLoss(zGrid0,Nz0,param(1),param(2),param(3),paramPerturb(2,4),param(5),param(6),1,1)];
momentPerturb5 = [ getLoss(zGrid0,Nz0,param(1),param(2),param(3),param(4),paramPerturb(1,5),param(6),1,1) - getLoss(zGrid0,Nz0,param(1),param(2),param(3),param(4),paramPerturb(2,5),param(6),1,1)];
momentPerturb6 = [ getLoss(zGrid0,Nz0,param(1),param(2),param(3),param(4),param(5),paramPerturb(1,6),1,1) - getLoss(zGrid0,Nz0,param(1),param(2),param(3),param(4),param(5),paramPerturb(2,6),1,1)];

Jacobian = round([ momentPerturb1(1,:)./(paramPerturb(1,1)-paramPerturb(2,1)) ; 
             momentPerturb2(1,:)./(paramPerturb(1,2)-paramPerturb(2,2)) ;
             momentPerturb3(1,:)./(paramPerturb(1,3)-paramPerturb(2,3)) ;
             momentPerturb4(1,:)./(paramPerturb(1,4)-paramPerturb(2,4)) ;
             momentPerturb5(1,:)./(paramPerturb(1,5)-paramPerturb(2,5)) ;
             momentPerturb6(1,:)./(paramPerturb(1,6)-paramPerturb(2,6)) ],3)';
         
%% Technological parameters %%

lambda = param(1); % meeting rate
chi = param(2); % productiivty reset rate
mu = param(3); % flow of potential firms
eta = param(4); % productivity dispersion
b =  param(5); % outside option of workers
delta =  param(6); % exogeneous job destruction rate

lambdaExp = paramExp(1); % meeting rate
chiExp = paramExp(2); % productiivty reset rate
muExp = paramExp(3); % flow of potential firms
etaExp = paramExp(4); % productivity dispersion
bExp =  paramExp(5); % outside option of workers
deltaExp =  paramExp(6); % exogeneous job destruction rate

lambdaExp2 = paramExp2(1); % meeting rate
chiExp2 = paramExp2(2); % productiivty reset rate
muExp2 = paramExp2(3); % flow of potential firms
etaExp2 = paramExp2(4); % productivity dispersion
bExp2 =  paramExp2(5); % outside option of workers
deltaExp2 =  paramExp2(6); % exogeneous job destruction rate

lambdaPareto = paramPareto(1); % meeting rate
chiPareto = paramPareto(2); % productiivty reset rate
muPareto = paramPareto(3); % flow of potential firms
etaPareto = paramPareto(4); % productivity dispersion
bPareto =  paramPareto(5); % outside option of workers
deltaPareto =  paramPareto(6); % exogeneous job destruction rate

lambdaExpPareto = paramExpPareto(1); % meeting rate
chiExpPareto = paramExpPareto(2); % productiivty reset rate
muExpPareto = paramExpPareto(3); % flow of potential firms
etaExpPareto = paramExpPareto(4); % productivity dispersion
bExpPareto =  paramExpPareto(5); % outside option of workers
deltaExpPareto =  paramExpPareto(6); % exogeneous job destruction rate

lambdaExpPareto2 = paramExpPareto2(1); % meeting rate
chiExpPareto2 = paramExpPareto2(2); % productiivty reset rate
muExpPareto2 = paramExpPareto2(3); % flow of potential firms
etaExpPareto2 = paramExpPareto2(4); % productivity dispersion
bExpPareto2 =  paramExpPareto2(5); % outside option of workers
deltaExpPareto2 =  paramExpPareto2(6); % exogeneous job destruction rate

lambdaBarEV = paramEV(1); % cost of vacancy
chiEV = paramEV(2); % productiivty reset rate
muEV = paramEV(3); % flow of potential firms
etaEV = paramEV(4); % productivity dispersion
bEV =  paramEV(5); % outside option of workers
deltaEV =  paramEV(6); % exogeneous job destruction rate
thetaEV = paramEV(7); % curvature of vacancy cost

lambdaBarEVexp = paramEVexp(1); % cost of vacancy
chiEVexp = paramEVexp(2); % productiivty reset rate
muEVexp = paramEVexp(3); % flow of potential firms
etaEVexp = paramEVexp(4); % productivity dispersion
bEVexp =  paramEVexp(5); % outside option of workers
deltaEVexp =  paramEVexp(6); % exogeneous job destruction rate
thetaEVexp = paramEVexp(7); % curvature of vacancy cost

lambdaBarEVexp2 = paramEVexp2(1); % cost of vacancy
chiEVexp2 = paramEVexp2(2); % productiivty reset rate
muEVexp2 = paramEVexp2(3); % flow of potential firms
etaEVexp2 = paramEVexp2(4); % productivity dispersion
bEVexp2 =  paramEVexp2(5); % outside option of workers
deltaEVexp2 =  paramEVexp2(6); % exogeneous job destruction rate
thetaEVexp2 = paramEVexp2(7); % curvature of vacancy cost
thetaEV2 = paramEVexp2(7); % curvature of vacancy cost

%% Solve models %%

% Solve EQ - Baseline
[zbar wbar zGrid vGrid wGrid] = getEQ(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,1);
[lsAgg lsAvg opCov u JDC JDD JCC JCB JC JD JR JRC JRBD rho lp9590 lp9050 lp5010 lp9010] = getModelOutputAgg(lambda,chi,mu,eta,b,delta,zbar,zGrid,vGrid,wGrid,1);
[nGrid nGridNorm sizePmf sizeCdf zeta betayls betanls] = getDistN(lambda,chi,mu,eta,b,delta,1);
[nShareDec yShareDec wRelDec lpRelDec lsDec] = getModelOutputByDecile(lambda,chi,mu,eta,b,delta,zbar,zGrid,vGrid,wGrid,1);
[wMean passthroughOLS wageElastQuits lsQuint yShareQuint nShareQuint lpQuint gammaGrid gammaGridInt pGridInt gamma0Grid pGrid gGrid lpGrid lsGrid varlogw varlogy covlogwlogy varlogwEmp logw_p5010 logw_p9050 logw_p9990] = getModelOutputMisc(lambda,chi,mu,eta,b,delta,zbar,zGrid,vGrid,wGrid,1);

% Solve EQ - Pareto
[zbarPareto wbarPareto zGridPareto vGridPareto wGridPareto] = getEQ(zGridPareto0,NzPareto0,lambdaPareto,chiPareto,muPareto,etaPareto,bPareto,deltaPareto,2);
[lsAggPareto lsAvgPareto opCovPareto uPareto JDCPareto JDDPareto JCCPareto JCBPareto JCPareto JDPareto JRPareto JRCPareto JRBDPareto rhoPareto lp9590Pareto lp9050Pareto lp5010Pareto lp9010Pareto] = getModelOutputAgg(lambdaPareto,chiPareto,muPareto,etaPareto,bPareto,deltaPareto,zbarPareto,zGridPareto,vGridPareto,wGridPareto,2);
[nShareDecPareto yShareDecPareto wRelDecPareto lpRelDecPareto lsDecPareto] = getModelOutputByDecile(lambdaPareto,chiPareto,muPareto,etaPareto,bPareto,deltaPareto,zbarPareto,zGridPareto,vGridPareto,wGridPareto,2);
[wMeanPareto passthroughOLSPareto  wageElastQuitsPareto lsQuintPareto yShareQuintPareto nShareQuintPareto lpQuintPareto gammaGridPareto gammaGridIntPareto pGridIntPareto gamma0GridPareto pGridPareto gGridPareto lpGridPareto lsGridPareto varlogwPareto varlogyPareto covlogwlogyPareto varlogwEmpPareto logw_p5010Pareto logw_p9050Pareto logw_p9990Pareto] = getModelOutputMisc(lambdaPareto,chiPareto,muPareto,etaPareto,bPareto,deltaPareto,zbarPareto,zGridPareto,vGridPareto,wGridPareto,2);

% Solve EQ - Benchmark models
Gamma0zbar = getGammacdf(zbar,eta,0,1);
[lsAggBm lsAvgBm opCovBm yShareDecBm nShareDecBm lsDecBm lp9010Bm yBm uBm] = getBmModelOutput(zGrid0,Nz0,Gamma0zbar,u,eta,1);
[lsAggCm lsAvgCm opCovCm yShareDecCm nShareDecCm lsDecCm lp9010Cm yCm uCm] = getCmModelOutput(zGrid0,Nz0,lambda,chi,mu,eta,Gamma0zbar,delta,1);

% Solve EQ - Endogenous vacancy extension
[zbarEV wbarEV zGridEV uEV lpGridEV vGridEV wGridEV PGridEV pGridEV QGridEV qGridEV lambdaGridEV LambdaEV gGridEV hGridEV sGridEV]  = getEQEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,1);
[lsAggEV lsAvgEV opCovEV uEV JDCEV JDDEV JCCEV JCBEV JCEV JDEV JREV JRCEV JRBDEV rhoEV lp9010EV passthroughOLSEV varlogwEmpEV DHFslopeEV] = getEVModelOutput(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,1);
[nShareDecEV yShareDecEV wRelDecEV lpRelDecEV lsDecEV] = getModelOutputByDecileEV(chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,zbarEV,zGridEV,vGridEV,wGridEV,uEV,pGridEV,PGridEV,lpGridEV,1);
costShareEV = (1/(1+thetaEV))*trapz(zGridEV,pGridEV.*vGridEV.*hGridEV)/trapz(zGridEV,pGridEV.*lpGridEV);

% Targeted moments
tableTargets = getLoss(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,1,1);
tableTargetsPareto = getLoss(zGridPareto0,NzPareto0,lambdaPareto,chiPareto,muPareto,etaPareto,bPareto,deltaPareto,1,2);
tableTargetsEV = getLossEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,1,1);

%% Model experiment %%

% Model experiment - Solve EQ - Baseline
[zbarExp wbarExp zGridExp vGridExp wGridExp] = getEQ(zGrid0,Nz0,lambdaExp,chiExp,muExp,etaExp,bExp,deltaExp,1);
[lsAggExp lsAvgExp opCovExp uExp JDCExp JDDExp JCCExp JCBExp JCExp JDExp JRExp JRCExp JRBDExp rhoExp lp9590Exp lp9050Exp lp5010Exp lp9010Exp] = getModelOutputAgg(lambdaExp,chiExp,muExp,etaExp,bExp,deltaExp,zbarExp,zGridExp,vGridExp,wGridExp,1);
[nShareDecExp yShareDecExp wRelDecExp lpRelDecExp lsDecExp] = getModelOutputByDecile(lambdaExp,chiExp,muExp,etaExp,bExp,deltaExp,zbarExp,zGridExp,vGridExp,wGridExp,1);
[wMeanExp passthroughOLSExp wageElastQuitsExp lsQuintExp yShareQuintExp nShareQuintExp lpQuintExp gammaGridExp gammaGridIntExp pGridIntExp gamma0GridExp pGridExp gGridExp lpGridExp lsGridExp varlogwExp varlogyExp covlogwlogyExp varlogwEmpExp logw_p5010Exp logw_p9050Exp logw_p9990Exp] = getModelOutputMisc(lambdaExp,chiExp,muExp,etaExp,bExp,deltaExp,zbarExp,zGridExp,vGridExp,wGridExp,1);
y = (1-u)*trapz(zGrid,lpGrid.*pGrid);
yExp = (1-uExp)*trapz(zGridExp,lpGridExp.*pGridExp);

% Model experiment - Solve EQ - Baseline (constant u)
[zbarExp2 wbarExp2 zGridExp2 vGridExp2 wGridExp2] = getEQ(zGrid0,Nz0,lambdaExp2,chiExp2,muExp2,etaExp2,bExp2,deltaExp2,1);
[lsAggExp2 lsAvgExp2 opCovExp2 uExp2 JDCExp2 JDDExp2 JCCExp2 JCBExp2 JCExp2 JDExp2 JRExp2 JRCExp2 JRBDExp2 rhoExp2 lp9590Exp2 lp9050Exp2 lp5010Exp2 lp9010Exp2] = getModelOutputAgg(lambdaExp2,chiExp2,muExp2,etaExp2,bExp2,deltaExp2,zbarExp2,zGridExp2,vGridExp2,wGridExp2,1);
[wMeanExp2 passthroughOLSExp2  wageElastQuitsExp2 lsQuintExp2 yShareQuintExp2 nShareQuintExp2 lpQuintExp2 gammaGridExp2 gammaGridIntExp2 pGridIntExp2 gamma0GridExp2 pGridExp2 gGridExp2 lpGridExp2 lsGridExp2 varlogwExp2 varlogyExp2 covlogwlogyExp2 varlogwEmpExp2 logw_p5010Exp2 logw_p9050Exp2 logw_p9990Exp2] = getModelOutputMisc(lambdaExp2,chiExp2,muExp2,etaExp2,bExp2,deltaExp2,zbarExp2,zGridExp2,vGridExp2,wGridExp2,1);
yExp2 = (1-uExp2)*trapz(zGridExp2,lpGridExp2.*pGridExp2);

% Model experiment - Solve EQ - Baseline (Pareto)
[zbarExpPareto wbarExpPareto zGridExpPareto vGridExpPareto wGridExpPareto] = getEQ(zGridPareto0,NzPareto0,lambdaExpPareto,chiExpPareto,muExpPareto,etaExpPareto,bExpPareto,deltaExpPareto,2);
[lsAggExpPareto lsAvgExpPareto opCovExpPareto uExpPareto JDCExpPareto JDDExpPareto JCCExpPareto JCBExpPareto JCExpPareto JDExpPareto JRExpPareto JRCExpPareto JRBDExpPareto rhoExpPareto lp9590ExpPareto lp9050ExpPareto lp5010ExpPareto lp9010ExpPareto] = getModelOutputAgg(lambdaExpPareto,chiExpPareto,muExpPareto,etaExpPareto,bExpPareto,deltaExpPareto,zbarExpPareto,zGridExpPareto,vGridExpPareto,wGridExpPareto,2);
[nShareDecExpPareto yShareDecExpPareto wRelDecExpPareto lpRelDecExpPareto lsDecExpPareto] = getModelOutputByDecile(lambdaExpPareto,chiExpPareto,muExpPareto,etaExpPareto,bExpPareto,deltaExpPareto,zbarExpPareto,zGridExpPareto,vGridExpPareto,wGridExpPareto,2);
[wMeanExpPareto passthroughOLSExpPareto  wageElastExpPareto lsQuintExpPareto yShareQuintExpPareto nShareQuintExpPareto lpQuintExpPareto gammaGridExpPareto gammaGridIntExpPareto pGridIntExpPareto gamma0GridExpPareto pGridExpPareto gGridExpPareto lpGridExpPareto lsGridExpPareto varlogwExpPareto varlogyExpPareto covlogwlogyExpPareto varlogwEmpExpPareto logw_p5010ExpPareto logw_p9050ExpPareto logw_p9990ExpPareto] = getModelOutputMisc(lambdaExpPareto,chiExpPareto,muExpPareto,etaExpPareto,bExpPareto,deltaExpPareto,zbarExpPareto,zGridExpPareto,vGridExpPareto,wGridExpPareto,2);
yPareto = (1-uPareto)*trapz(zGridPareto,lpGridPareto.*pGridPareto);
yExpPareto = (1-uExpPareto)*trapz(zGridExpPareto,lpGridExpPareto.*pGridExpPareto);

% Model experiment - Solve EQ - Baseline (Pareto, constant u)
[zbarExpPareto2 wbarExpPareto2 zGridExpPareto2 vGridExpPareto2 wGridExpPareto2] = getEQ(zGridPareto0,NzPareto0,lambdaExpPareto2,chiExpPareto2,muExpPareto2,etaExpPareto2,bExpPareto2,deltaExpPareto2,2);
[lsAggExpPareto2 lsAvgExpPareto2 opCovExpPareto2 uExpPareto2 JDCExpPareto2 JDDExpPareto2 JCCExpPareto2 JCBExpPareto2 JCExpPareto2 JDExpPareto2 JRExpPareto2 JRCExpPareto2 JRBDExpPareto2 rhoExpPareto2 lp9590ExpPareto2 lp9050ExpPareto2 lp5010ExpPareto2 lp9010ExpPareto2] = getModelOutputAgg(lambdaExpPareto2,chiExpPareto2,muExpPareto2,etaExpPareto2,bExpPareto2,deltaExpPareto2,zbarExpPareto2,zGridExpPareto2,vGridExpPareto2,wGridExpPareto2,2);
[nShareDecExpPareto2 yShareDecExpPareto2 wRelDecExpPareto2 lpRelDecExpPareto2 lsDecExpPareto2] = getModelOutputByDecile(lambdaExpPareto2,chiExpPareto2,muExpPareto2,etaExpPareto2,bExpPareto2,deltaExpPareto2,zbarExpPareto2,zGridExpPareto2,vGridExpPareto2,wGridExpPareto2,2);
[wMeanExpPareto2 passthroughOLSExpPareto2  wageElastQuitsExpPareto2 lsQuintExpPareto2 yShareQuintExpPareto2 nShareQuintExpPareto2 lpQuintExpPareto2 gammaGridExpPareto2 gammaGridIntExpPareto2 pGridIntExpPareto2 gamma0GridExpPareto2 pGridExpPareto2 gGridExpPareto2 lpGridExpPareto2 lsGridExpPareto2 varlogwExpPareto2 varlogyExpPareto2 covlogwlogyExpPareto2 varlogwEmpExpPareto2 logw_p5010ExpPareto2 logw_p9050ExpPareto2 logw_p9990ExpPareto2] = getModelOutputMisc(lambdaExpPareto2,chiExpPareto2,muExpPareto2,etaExpPareto2,bExpPareto2,deltaExpPareto2,zbarExpPareto2,zGridExpPareto2,vGridExpPareto2,wGridExpPareto2,2);
yExpPareto2 = (1-uExpPareto2)*trapz(zGridExpPareto2,lpGridExpPareto2.*pGridExpPareto2);

% Model experiment - Solve EQ - Benchmark models
[lsAggBmExp lsAvgBmExp opCovBmExp yShareDecBmExp nShareDecBmExp lsDecBmExp lp9010BmExp yBmExp uBmExp] = getBmModelOutput(zGrid0,Nz0,Gamma0zbar,u,etaExpCmBm,1);
[lsAggCmExp lsAvgCmExp opCovCmExp yShareDecCmExp nShareDecCmExp lsDecCmExp lp9010CmExp yCmExp uCmExp] = getCmModelOutput(zGrid0,Nz0,lambda,chi,mu,etaExpCmBm,Gamma0zbar,delta,1);

% Model experiment - Solve EQ - Endogenous vacancy extension
[zbarEVexp wbarEVexp zGridEVexp uEVexp lpGridEVexp vGridEVexp wGridEVexp PGridEVexp pGridEVexp QGridEVexp qGridEVexp lambdaGridEVexp LambdaEVexp gGridEVexp hGridEVexp sGridEVexp]  = getEQEV(zGrid0,Nz0,chiEVexp,muEVexp,etaEVexp,bEVexp,deltaEVexp,thetaEVexp,lambdaBarEVexp,1);
[lsAggEVexp lsAvgEVexp opCovEVexp uEVexp JDCEVexp JDDEVexp JCCEVexp JCBEVexp JCEVexp JDEVexp JREVexp JRCEVexp JRBDEVexp rhoEVexp lp9010EVexp passthroughOLSEVexp varlogwEVexp] = getEVModelOutput(zGrid0,Nz0,chiEVexp,muEVexp,etaEVexp,bEVexp,deltaEVexp,thetaEVexp,lambdaBarEVexp,1);
yEV = (1-uEV)*trapz(zGridEV,lpGridEV.*pGridEV);
yEVExp = trapz(zGridEVexp,lpGridEVexp.*pGridEVexp);

% Model experiment - Solve EQ - Endogenous vacancy extension (constant u)
[zbarEVexp2 wbarEVexp2 zGridEVexp2 uEVexp2 lpGridEVexp2 vGridEVexp2 wGridEVexp2 PGridEVexp2 pGridEVexp2 QGridEVexp2 qGridEVexp2 lambdaGridEVexp2 LambdaEVexp2 gGridEVexp2 hGridEVexp2 sGridEVexp2]  = getEQEV(zGrid0,Nz0,chiEVexp2,muEVexp2,etaEVexp2,bEVexp2,deltaEVexp2,thetaEVexp2,lambdaBarEVexp2,1);
[lsAggEVexp2 lsAvgEVexp2 opCovEVexp2 uEVexp2 JDCEVexp2 JDDEVexp2 JCCEVexp2 JCBEVexp2 JCEVexp2 JDEVexp2 JREVexp2 JRCEVexp2 JRBDEVexp2 rhoEVexp2 lp9010EVexp2 passthroughOLSEVexp2 varlogwEVexp2] = getEVModelOutput(zGrid0,Nz0,chiEVexp2,muEVexp2,etaEVexp2,bEVexp2,deltaEVexp2,thetaEVexp2,lambdaBarEVexp2,1);
yEVexp2 = trapz(zGridEVexp2,lpGridEVexp2.*pGridEVexp2);

% Targeted moments
tableTargetsExp = getLossExp(zGrid0,Nz0,lambdaExp,chiExp,muExp,etaExp,bExp,deltaExp,1,1);
tableTargetsExp2 = getLossExp(zGrid0,Nz0,lambdaExp2,chiExp2,muExp2,etaExp2,bExp2,deltaExp2,1,1);
tableTargetsExpPareto = getLossExp(zGridPareto0,NzPareto0,lambdaExpPareto,chiExpPareto,muExpPareto,etaExpPareto,bExpPareto,deltaExpPareto,1,2);
tableTargetsExpPareto2 = getLossExp(zGridPareto0,NzPareto0,lambdaExpPareto2,chiExpPareto2,muExpPareto2,etaExpPareto2,bExpPareto2,deltaExpPareto2,1,2);
tableTargetsEVExp = getLossEVexp(zGrid0,Nz0,chiEVexp,muEVexp,etaEVexp,bEVexp,deltaEVexp,thetaEVexp,lambdaBarEVexp,1,1);
tableTargetsEVExp2 = getLossEVexp(zGrid0,Nz0,chiEVexp2,muEVexp2,etaEVexp2,bEVexp2,deltaEVexp2,thetaEVexp2,lambdaBarEVexp2,1,1);

% Shift-share decomposition
ShiftShare = 100*[yShareDec'*(lsDecExp-lsDec) (yShareDecExp-yShareDec)'*lsDec (yShareDecExp-yShareDec)'*(lsDecExp-lsDec) ];

% Slope
lp9010diff = lp9010Exp-lp9010;
betaExp = (lsAggExp-lsAgg)/lp9010diff;
betaAvgExp = (lsAvgExp-lsAvg)/lp9010diff;
betaLs = (lsQuintExp-lsQuint)/lp9010diff;
betayShare = (yShareQuintExp-yShareQuint)/lp9010diff;
betanShare = (nShareQuintExp-nShareQuint)/lp9010diff;