%% Objects %%
B=200000; % number of firms
dt=1/12; % periods per year
T=115/dt; % number of years

Z=zeros(B,T); % TFP matrix
N=zeros(B,T); % size matrix
D=zeros(B,T); % death indicator matrix

distributionType=1;
Gamma0zbar = getGammacdf(zbar,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar);

PFunc = @(z) getPcdf(z,zbar,lambda,chi,mu,eta,b,delta,u,1);
gFunc = @(z) lambda*u + lambda*(1-u)*PFunc(z) - lambda*(1-u)*(1-PFunc(z))-delta;
qFunc = @(z) lambda*(1-u).*(1-PFunc(z))+delta;
Nbar = (1-u)/( (muE/chiX)*u );

Z(:,1) = getGammaquant(unifrnd(0,1,B,1),eta,zbar,distributionType);
N(:,1) = Nbar*(chi+delta-lambda*u)./(chi - gFunc(Z(:,1)));
D(:,1) = 0;

%% Simulate panel dataset %%
for t=2:T
    D(:,t) = D(:,t-1) + 1*(unifrnd(0,1,B,1)<dt*chiX);
    exit = find(D(:,t) - D(:,t-1) == 1);
    cont = find(D(:,t) - D(:,t-1) == 0);

        N(cont,t)=N(cont,t-1).*(1+dt*gFunc(Z(cont,t-1)));
        rand=unifrnd(0,1,length(cont),1);
        shock = find(rand<chiS*dt & cont);
        Z(cont,t)=Z(cont,t-1);
        Z(shock,t) = getGammaquant(unifrnd(0,1,length(shock),1),eta,zbar,distributionType);
    
        N(exit,t)=1;
        rand=unifrnd(0,1,length(exit),1);
        Z(exit,t)= getGammaquant(unifrnd(0,1,length(exit),1),eta,zbar,distributionType); 
end


id = reshape(repmat(1:B,[16/dt 1]),[B*16/dt 1]);
time = repmat((T+1-16/dt):T,[1 B])';

Qrate = qFunc(Z);
D=reshape(D(:,T+1-16/dt:T)',[B*16/dt 1]);
N=reshape(N(:,T+1-16/dt:T)',[B*16/dt 1]);
Qrate=reshape(Qrate(:,T+1-16/dt:T)',[B*16/dt 1]);

cons = (alpha/R)^(1/(1-alpha));
Y = (cons^alpha)*reshape(Z(:,T+1-16/dt:T)',[B*16/dt 1]).^(1/(1-alpha));
W = reshape(interpn([zbar zGrid(2:end)],wGrid,Z(:,T+1-16/dt:T)'),[B*16/dt 1]);

T = table(id,time,D, N, Y, W, Qrate);

%% Save the panel dataset %%
writetable(T,'SimulatedData.csv')

