%% Set up environment for figures %%
set(0,'DefaultTextInterpreter','latex')
set(0,'DefaultAxesTickLabelInterpreter','latex');
set(0,'DefaultLegendInterpreter', 'latex')
set(0,'DefaultTextFontSize', 22)
set(0,'DefaultAxesFontSize', 22)
set(0,'DefaultLineLineWidth',5)
blue_egb = [68 118 170]/255;
red_egb = [204 102 119]/255;
yellow_egb = [221 170 51]/255;
green_egb = [102 204 187]/255;

%% Load external data %%
load('../Data/Admin data/NALMFdata.mat');

simulatedMoments = table2array(readtable('simulatedMoments.csv'));

crossCountry = readtable('../Data/Cross country/crossCountry.csv');
crossCountryData = table2array(crossCountry(1:14,4:7));
crossCountryLbl = crossCountry(1:14,2:3);

lpls = readtable('../Data/Public data/lpls.csv');
lplsData = str2double(table2array(lpls(2:4,2:5)));


%% Table 2 - Externally calibrated parameter %%
table2 = round([r -log(1-0.148) alpha]',3);
writematrix(table2,'../Tables/table2.csv')

%% Table 3 - Targeted moments %%
table3 = round([ tableTargets([2 1],5:7) tableTargets([2 1],1:4) ]',3);
writematrix(table3,'../Tables/table3.csv')

%% Table 4 - Aggregate labor share decomposition %%
table4 = round([0.653 0.884 -0.231 ; lsAgg lsAvg opCov ; lsAggCm lsAvgCm opCovCm ; lsAggBm lsAvgBm opCovBm],3);
writematrix(table4,'../Tables/table4.csv')

%% Table 5 - Assessing cross-sectional moments %%
table5 = [ -0.313 round(betayls,3) -0.313 betayls NaN NaN ; ...
            0.002 NaN 0.002 NaN NaN NaN; ...
            NaN NaN 0.009 0 -0.001 round(betanls,3); ...
            NaN NaN 0.001 NaN 0.001 NaN];
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv
writematrix(table5,'../Tables/table5.csv')

%% Table 6 - Replication of Kline et al. %%
table6 = round([0.47 passthroughOLS ; -1.62 wageElastQuits],2);
writematrix(table6,'../Tables/table6.csv')

%% Table 7 - Wage distribution %%
table7 = round([0.73 varlogwEmp ; 1.32 logw_p9990; 0.78 logw_p9050; 0.75 logw_p5010; 0.07 0.1*varlogwEmp; 0.03 0.01],2) ;
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv
writematrix(table7,'../Tables/table7.csv')

%% Table 8 - Motivating evidence %%
table8 = [ round(lplsData,3) ; round(100*(lplsData(3,1:2)-lplsData(1,1:2)),1) round((lplsData(3,3:4)-lplsData(1,3:4)),2)  ];
writematrix(table8,'../Tables/table8.csv')

%% Table 9 - Response of aggregates (model experiment) %%
table9 = [round([lsAgg lsAggExp],3) round(100*(lsAggExp-lsAgg),2); ...
 round([lsAvg lsAvgExp],3) round(100*(lsAvgExp-lsAvg),2); ...
 round([opCov opCovExp],3) round(100*(opCovExp-opCov),2); ...
 round([alpha alpha],3) 0; ...
 round([1-alpha-lsAgg 1-alpha-lsAggExp],3) round(-100*(lsAggExp-lsAgg),2); ...
 round([y yExp],3) round(100*(yExp/y-1),2); ...
 round([u uExp],3) round(100*(uExp-u),2) ];
writematrix(table9,'../Tables/table9.csv')

%% Equation 4.1 - Shift-share decomposition (model experiment) %%
eq41 = round([100*(lsAggExp-lsAgg) ShiftShare ],2);
writematrix(eq41,'../Tables/eq41.csv')

%% Table 10 - Cross-industry regressions %%
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv

%% Table 11 - Model experiment: extensions and robustness checks %%
table11 = [ round(lsAgg,3) round(100*(yExp/y-1),2) round(100*(uExp-u),2) round(100*(lsAggExp-lsAgg),2) ; ... 
    round(lsAggCm,3) round(100*(yCmExp/yCm-1),2) round(100*(uCmExp-uCm),2) round(100*(lsAggCmExp-lsAggCm),2) ; ...
    round(lsAggBm,3) round(100*(yBmExp/yBm-1),2) round(100*(uBmExp-uBm),2) round(100*(lsAggBmExp-lsAggBm),2) ; ...
    round(lsAgg,3) round(100*(yExp2/y-1),2) round(100*(uExp2-u),2) round(100*(lsAggExp2-lsAgg),2) ; ...
    round(lsAggEV,3) round(100*(yEVExp/yEV-1),2) round(100*(uEVexp-uEV),2) round(100*(lsAggEVexp-lsAggEV),2) ; ...
    round(lsAggEV,3) round(100*(yEVexp2/yEV-1),2) 0 round(100*(lsAggEVexp2-lsAggEV),2) ; ...
    round(lsAggPareto,3) round(100*(yExpPareto/yPareto-1),2) round(100*(uExpPareto-uPareto),2) round(100*(lsAggExpPareto-lsAggPareto),2) ; ...
    round(lsAggPareto,3) round(100*(yExpPareto2/yPareto-1),2) 0 round(100*(lsAggExpPareto2-lsAggPareto),2)] ;
writematrix(table11,'../Tables/table11.csv')

%% Table 12 - Choice of productivity distribution Gamma_0 %%
table12 = round([lp9050Data+lp5010Data  (lp9050Data-lp5010Data)/(lp9050Data+lp5010Data) ;
 lp9050+lp5010  (lp9050-lp5010)/(lp9050+lp5010)  ;
 lp9050Pareto+lp5010Pareto  (lp9050Pareto-lp5010Pareto)/(lp9050Pareto+lp5010Pareto) ],3);
writematrix(table12,'../Tables/table12.csv')


%% Table 13 - Jacobian %%
table13 = round([ Jacobian(5:7,:) ; Jacobian(1:4,:)],3);
writematrix(table13,'../Tables/table13.csv')

%% Table 14 - Alternative calibrations %%
table14 = round([ [tableTargets(2,5:7) tableTargets(2,1:4) 0.0469]' ... % Data
  [tableTargets(1,5:7) tableTargets(1,1:4) 0]' ... % Baseline model
  [tableTargets(1,5:7) tableTargets(1,1:4) 0]' ... % Coles-Mortensen
  [tableTargets(1,5) 0 tableTargets(1,7) zeros(1,4) 0.0469]' ... % Burdett-Mortensen
  [tableTargetsEV(1,5:7) tableTargetsEV(1,1:4) 0]' ... % Endogenous-lambda
  [tableTargetsPareto(1,5:7) tableTargetsPareto(1,1:4) 0]' ... % Pareto
],3);
writematrix(table14,'../Tables/table14.csv')

%% Table 15 - %%
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv

%% Table 16 - Moments by labor productivity %%
table16 = round([lpRelDecData' ; KRelDecData' ; yShareDecData' ; lsDecData'],3);
writematrix(table16,'../Tables/table13.csv')

%% Table 17 -  %%
table17 = round([ 1982	0.965	0.9501621 ; ...
                  1987	0.949	1.024361 ; ...
                  1992	1.02	1.047524 ; ...
                  1997	1.113	1.185142 ; ...
                  2002	1.126	1.162317 ; ...
                  2007	1.265	1.473561],3);
writematrix(table17,'../Tables/table17.csv')

%% Table 18 - Summary statistics %%
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv

%% Table 19 - Assessing cross-sectional moment (additional specifications). %%
% Raw data for regression results is available at /Data/Admin data/NALMFreg.csv
                       
%% Table 20 - Wages and labor share in the cross-section of firms %%
table20 = round([1 - (covlogwlogyData/varlogyData)*(varlogyData/varlogwData) 1 - (covlogwlogy/varlogy)*(varlogy/varlogw) ;
           (covlogwlogyData/varlogyData) (covlogwlogy/varlogy) ;
           (varlogyData/varlogwData) (varlogy/varlogw)],2); 
writematrix(table20,'../Tables/table20.csv')
    
%% Table 21 - Cross-country regressions %%
% Raw data for regression results is available at /Data/Cross
% country/CCreg.csv

       
%% Figure 1 - Labor share and productivity (numerical examples) %%
plot(0:20,0.8*ones(21,1),'--','Color',[0.5 0.5 0.5])
hold on
plot(lpGridPareto/trapz(zGridPareto,lpGridPareto.*pGridPareto),lsGridPareto,'-','Color',blue_egb)
xlabel('Productivity $y$')
ylabel('Labor share')
axis([0 5 0 1.2])
yticks([0 0.2 0.4 0.6 0.8 1 1.2])
legend('Frictionless','Model','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsModel.eps','epsc');

epsGrid = 0:0.1:1;
lsFL = epsGrid.^0*0.8;
lsBL = 0.8*(1-epsGrid*(1/3));
lsCM = 0.8*(1-epsGrid*(2/3));
lsBM = 0.8*(1-epsGrid*(3/3));

plot(epsGrid,lsFL,'--','Color',[0.5 0.5 0.5])
hold on
plot(epsGrid,lsBL,'-o','Color',blue_egb)
hold on
plot(epsGrid,lsCM,'-.','Color',red_egb)
hold on
plot(epsGrid,lsBM,'-d','Color',yellow_egb)
xlabel('Productivity dispersion $var(\log y)$')
ylabel('Aggregate labor share')
axis([0 1 0 1.2])
legend('Frictionless','Model','Coles-Mortensen','Burdett-Mortensen','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsharePareto.eps','epsc');

%% Figure 2 - Aggregate labor share decomposition %%
plot(1:10,lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,lsDecData,'-','Color',red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Labor share')
axis([1 10 0.25 2])
yticks([0.5 1 1.5 2])
xticks(2:2:10)
legend('Model','Data','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDec.eps','epsc');

plot(1:10,yShareDec,'-o','Color',blue_egb)
hold on
plot(1:10,yShareDecData,'-','Color',red_egb)
xlabel('Labor productivity decile')
ylabel('Value-added share')
axis([1 10 0 0.6])
yticks([0.2 0.4 0.6])
legend('Model','Data','Location','Northwest')
grid on
hold off
saveas(gca,'..\Figures\yShareDec.eps','epsc');

%% Figure 3 - Assessing panel moments %%

plot(simulatedMoments(:,1),simulatedMoments(:,3),'-o','Color',blue_egb)
hold on
plot(simulatedMoments(:,1),betawyData,'-','Color',red_egb)
hold on
plot(simulatedMoments(:,1),zeros(1,6),'--','Color',[0.5 0.5 0.5])
xlabel('Horizon (year)')
ylabel('Wage')
legend('Model','Data','Location','Northeast')
axis([0 5 -0.4 1.2])
yticks(-0.4:0.4:1.2)
grid on
hold off
saveas(gca,'..\Figures\panel_yw.eps','epsc');

plot(simulatedMoments(:,1),simulatedMoments(:,2),'-o','Color',blue_egb)
hold on
plot(simulatedMoments(:,1),betagwData,'-','Color',red_egb)
hold on
plot(simulatedMoments(:,1),zeros(1,6),'--','Color',[0.5 0.5 0.5])
xlabel('Horizon (year)')
ylabel('Cumulative employment growth')
legend('Model','Data','Location','Northeast')
grid on
hold off
axis([0 5 -0.4 1.2])
yticks(-0.4:0.4:1.2)
saveas(gca,'..\Figures\panel_wg.eps','epsc');

%% Figure 4 - Response of labor shares and value-added shares (counterfactual experiment) %%
plot(1:10,lsDecExp-lsDec,'o-','Color',blue_egb)
hold on
plot(1:10,zeros(1,10),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Labor share change')
axis([1 10 -0.1 0.5])
grid on
hold off
saveas(gcf,'..\Figures\lsDecExp.eps','epsc');

plot(1:10,yShareDecExp-yShareDec,'o-','Color',blue_egb)
hold on
plot(1:10,zeros(1,10),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Value-added share change')
axis([1 10 -0.01 0.05])
grid on
hold off
saveas(gcf,'..\Figures\yShareDecExp.eps','epsc');

%% Figure 5 - Response of labor shares and value-added shares (model experiment versus data) %%
plot(1:5,betaLs,'o-','Color',blue_egb)
hold on
plot(1:5,betaLsData,'-','Color',red_egb)
hold on
shade(1:5,betaLsData-1.96*sigmaLsData,'--',1:5,betaLsData+1.96*sigmaLsData,'--','FillType',[1 2;2 1],'Color',0.4*[1 1 1] + 0.6*red_egb)
xlabel('Labor productivity quintile')
ylabel('Labor share change')
ylim([-.55 1.5])
yticks([-0.5 0 0.5 1 1.5])
grid on
legend('Model','Data','95\% CI','Location','Northeast')
hold off
saveas(gcf,'..\Figures\betaLs.eps','epsc');

plot(1:5,betayShare,'-o','Color',blue_egb)
hold on
plot(1:5,betayShareData,'-','Color',red_egb)
hold on
shade(1:5,betayShareData-1.96*sigmayShareData,'--',1:5,betayShareData+1.96*sigmayShareData,'--','FillType',[1 2;2 1],'Color',0.4*[1 1 1] + 0.6*red_egb)
xlabel('Labor productivity quintile')
ylabel('Value-added share change')
ylim([-0.2 0.3])
yticks([-0.2:0.1:0.3])
grid on
legend('Model','Data','95\% CI','Location','Northeast')
hold off
saveas(gcf,'..\Figures\betayShare.eps','epsc');

%% Figure 6 - Productivity dispersion and the labor share across industries and countries %%
indstGrp1 = indstYear(:,7)==1;
indstGrp2 = indstYear(:,7)==2;
indstGrp3 = indstYear(:,7)==3;
indstGrp4 = indstYear(:,7)==4;

labelSiz=17;
xDelta = 0.075;
Xlvl = [ones(length(indstYear(:,4)),1) indstYear(:,4)];
Ylvl = indstYear(:,3);
betalvl = Xlvl\Ylvl;
plot(indstYear(indstGrp1,4),indstYear(indstGrp1,3),'o','Color',blue_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp2,4),indstYear(indstGrp2,3),'D','Color',red_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp4,4),indstYear(indstGrp4,3),'s','Color',green_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp3,4),indstYear(indstGrp3,3),'^','Color',yellow_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(1:4,betalvl(1) + betalvl(2)*(1:4),'--','Color',0.6*[1 1 1])
hold on
text(3.33,0.875,append('$\widehat{\beta}=$',string(round(betalvl(2),3))),'Color',0.3*[1 1 1],'FontSize',20)
hold on
axis([1 4 0 1])
yticks(0:0.25:1)
xticks(1:4)
ylabel('Labor share')
legend('Goods-producing','Trade','Professional services','Other services','Location','Southwest','NumColumns',2)
grid on
hold off
saveas(gca,'..\Figures\scatterIndstLvl.eps','epsc');


labelSiz=17;
xDelta = 0.035;
Xdiff = [ones(length(indstYear(:,6)),1) indstYear(:,6)];
Ydiff = indstYear(:,5);
betadiff = Xdiff\Ydiff;
plot(indstYear(indstGrp1,6),indstYear(indstGrp1,5),'o','Color',blue_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp2,6),indstYear(indstGrp2,5),'D','Color',red_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp4,6),indstYear(indstGrp4,5),'s','Color',green_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(indstYear(indstGrp3,6),indstYear(indstGrp3,5),'^','Color',yellow_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(-1.5:0.25:1.5,betadiff(1) + betadiff(2)*(-1.5:0.25:1.5),'--','Color',0.6*[1 1 1])
hold on
text(0.4,0.3,append('$\widehat{\beta}=$',string(round(betadiff(2),3))),'Color',0.3*[1 1 1],'FontSize',20)
axis([-0.8 0.8 -0.4 0.4])
yticks(-0.4:0.2:0.4)
xticks(-0.8:0.4:0.8)
legend('Goods-producing','Trade','Professional services','Other services','Location','Southwest','NumColumns',2)
grid on
hold off
saveas(gca,'..\Figures\scatterIndstDiff.eps','epsc');

labelSiz=16;
xDelta = 0.05;
XccLvl = [ones(length(crossCountryData(:,2)),1) crossCountryData(:,1)];
YccLvl = crossCountryData(:,2);
betaccLvl = XccLvl\YccLvl;
plot(crossCountryData(1:2:13,1),crossCountryData(1:2:13,2),'o','Color',blue_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(crossCountryData(2:2:14,1),crossCountryData(2:2:14,2),'D','Color',red_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(1:0.5:2.5,betaccLvl(1) + betaccLvl(2)*(1:0.5:2.5),'--','Color',0.6*[1 1 1])
text(2.15,0.725,append('$\widehat{\beta}=$',string(round(betaccLvl(2),3))),'Color',0.3*[1 1 1],'FontSize',20)
axis([1 2.5 0.2 0.8])
yticks(0:0.2:0.8)
xticks(1:0.5:2.5)
xlabel('Productivity dispersion')
ylabel('Labor share')
legend('Manufacturing','Non-financial services','Location','Southwest')
grid on
hold off
text(crossCountryData(1,1)+xDelta,crossCountryData(1,2),'DNK','FontSize',labelSiz)
text(crossCountryData(3,1)+xDelta,crossCountryData(3,2),'FIN','FontSize',labelSiz)
text(crossCountryData(5,1)+xDelta,crossCountryData(5,2),'FRA','FontSize',labelSiz)
text(crossCountryData(7,1)+xDelta,crossCountryData(7,2),'ITA','FontSize',labelSiz)
text(crossCountryData(9,1)+xDelta,crossCountryData(9,2),'JPN','FontSize',labelSiz)
text(crossCountryData(11,1)+xDelta,crossCountryData(11,2),'NOR','FontSize',labelSiz)
text(crossCountryData(13,1)+xDelta,crossCountryData(13,2),'NZL','FontSize',labelSiz)
text(crossCountryData(2,1)+xDelta,crossCountryData(2,2),'DNK','FontSize',labelSiz)
text(crossCountryData(4,1)+xDelta,crossCountryData(4,2),'FIN','FontSize',labelSiz)
text(crossCountryData(6,1)+xDelta,crossCountryData(6,2),'FRA','FontSize',labelSiz)
text(crossCountryData(8,1)+xDelta,crossCountryData(8,2),'ITA','FontSize',labelSiz)
text(crossCountryData(10,1)+xDelta,crossCountryData(10,2),'JPN','FontSize',labelSiz)
text(crossCountryData(12,1)+xDelta,crossCountryData(12,2),'NOR','FontSize',labelSiz)
text(crossCountryData(14,1)+xDelta,crossCountryData(14,2),'NZL','FontSize',labelSiz)
saveas(gca,'..\Figures\scatterCcLvl.eps','epsc');

labelSiz=16;
xDelta = 0.01;
XccDiff = [ones(length(crossCountryData(:,3)),1) crossCountryData(:,3)];
YccDiff = crossCountryData(:,4);
betaccDiff = XccDiff\YccDiff;
plot(crossCountryData(1:2:13,3),crossCountryData(1:2:13,4),'o','Color',blue_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(crossCountryData(2:2:14,3),crossCountryData(2:2:14,4),'D','Color',red_egb,'linewidth',3,'MarkerSize',10)
hold on
plot(-0.2:0.01:0.3,betaccDiff(1) + betaccDiff(2)*(-0.2:0.01:0.3),'--','Color',0.6*[1 1 1])
text(0.175,0.095,append('$\widehat{\beta}=$',string(round(betaccDiff(2),3))),'Color',0.3*[1 1 1],'FontSize',20)
axis([-0.1 0.25 -0.05 0.12])
xticks(-0.1:0.1:0.2)
xlabel('Productivity dispersion')
legend('Manufacturing','Non-financial services','Location','Southwest')
grid on
hold off
text(crossCountryData(1,3)+xDelta,crossCountryData(1,4),'DNK','FontSize',labelSiz)
text(crossCountryData(3,3)+xDelta,crossCountryData(3,4),'FIN','FontSize',labelSiz)
text(crossCountryData(5,3)+xDelta,crossCountryData(5,4),'FRA','FontSize',labelSiz)
text(crossCountryData(7,3)+xDelta,crossCountryData(7,4),'ITA','FontSize',labelSiz)
text(crossCountryData(9,3)+xDelta,crossCountryData(9,4),'JPN','FontSize',labelSiz)
text(crossCountryData(11,3)+xDelta,crossCountryData(11,4),'NOR','FontSize',labelSiz)
text(crossCountryData(13,3)+xDelta,crossCountryData(13,4),'NZL','FontSize',labelSiz)
text(crossCountryData(2,3)+xDelta,crossCountryData(2,4),'DNK','FontSize',labelSiz)
text(crossCountryData(4,3)+xDelta,crossCountryData(4,4),'FIN','FontSize',labelSiz)
text(crossCountryData(6,3)+xDelta,crossCountryData(6,4),'FRA','FontSize',labelSiz)
text(crossCountryData(8,3)+xDelta,crossCountryData(8,4),'ITA','FontSize',labelSiz)
text(crossCountryData(10,3)+xDelta,crossCountryData(10,4),'JPN','FontSize',labelSiz)
text(crossCountryData(12,3)+xDelta,crossCountryData(12,4),'NOR','FontSize',labelSiz)
text(crossCountryData(14,3)+xDelta,crossCountryData(14,4),'NZL','FontSize',labelSiz)
saveas(gca,'..\Figures\scatterCcDiff.eps','epsc');


%% Figure 7 - Hiring and wages in the endogenous-lambda extension (calibrated model) %%
PGrid = getPcdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,2);
hGrid = lambda*(u+(1-u)*PGrid);
plot(log(hGrid/lambda),log(hGrid),'-','Color',blue_egb)
hold on
plot(log(hGridEV./lambdaGridEV),log(hGridEV),'-.','Color',red_egb)
xlabel('Hiring rate (log)')
ylabel('Vacancy yield (log)')
axis([-3 0 -5 0])
legend('Baseline (slope=1)','Endogenous-$\lambda$ (slope=0.82)','Location','Northwest')
grid on
hold off
saveas(gca,'..\Figures\EV_DHF.eps','epsc');

wGridRel = wGrid/trapz(zGrid,wGrid.*pGrid);
wGridRelEV = wGridEV/trapz(zGridEV,wGridEV.*pGridEV);
PGrid = getPcdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,1);
hGrid = lambda*(u+(1-u)*PGrid);
[varlogwEmp varlogwEmpEV];

plot([wGridRel(1) wGridRel],[0 pGrid],'-','Color',blue_egb)
hold on
plot([wGridRelEV(1) wGridRelEV],[0 pGridEV],'-.','Color',red_egb)
hold on
axis([0.5 2.5 0 0.8])
xlabel('Relative wage')
ylabel('Density')
legend('Baseline ($\sigma^2_{\log w} = 0.15$)','Endogenous-$\lambda$ ($\sigma^2_{\log w} = 0.12$)','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\EV_wageDist.eps','epsc');

%% Figure 9 - Labor share in the National Accounts and in the main sample %%
plot(1961:2015,LS_19612015,'-','Color',red_egb)
xlabel('Year')
ylabel('Labor share')
ylim([0.6 0.75])
grid on
hold off
saveas(gcf,'..\Figures\LS_NAC.eps','epsc');

plot(2000:2015,laborshare_valid(:,1),'-','Color',red_egb)
hold on
plot(2000:2015,laborshare_valid(:,2),'-o','Color',blue_egb)
xlabel('Year')
ylabel('Labor share')
ylim([0.6 0.75])
grid on
legend('National Accounts','Sample','Location','Northwest')
hold off
saveas(gcf,'..\Figures\LS_NAC_SMP.eps','epsc');


%% Figure 10 - Moments by labor productivity decile %%
plot(1:10,lsDec,'o-','Color',blue_egb)
hold on
plot(1:10,lsDecIndstGrpData(:,1),'-.','Color',0.8*[1 1 1]+ 0.2*red_egb)
hold on
plot(1:10,lsDecIndstGrpData(:,2),'-x','Color',0.6*[1 1 1] + 0.4*red_egb)
hold on
plot(1:10,lsDecIndstGrpData(:,4),'-d','Color',0.4*[1 1 1]+ 0.6*red_egb)
hold on
plot(1:10,lsDecIndstGrpData(:,3),'-o','Color',0.2*[1 1 1] + 0.8*red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.25 0.25 0.25])
xlabel('Labor productivity decile')
ylabel('Labor share')
axis([1 10 0.25 2])
legend('Model','Data (goods)','Data (trade)','Data (professional sv.)','Data (other sv.)','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDecIndstGrp.eps','epsc');

plot(1:10,lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,lsDecEmpGrpData(:,1),'-.','Color',0.8*[1 1 1]+ 0.2*red_egb)
hold on
plot(1:10,lsDecEmpGrpData(:,2),'-x','Color',0.6*[1 1 1]+ 0.4*red_egb)
hold on
plot(1:10,lsDecEmpGrpData(:,3),'-d','Color',0.4*[1 1 1]+ 0.6*red_egb)
hold on
plot(1:10,lsDecEmpGrpData(:,4),'-o','Color',0.2*[1 1 1]+ 0.8*red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.25 0.25 0.25])
xlabel('Labor productivity decile')
ylabel('Labor share')
axis([1 10 0.25 2])
legend('Model','Data (5-20)','Data (20-100)','Data (100-500)','Data (500+)','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDecEmpGrp.eps','epsc');

plot(1:10,lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,lsDecData,'-','Color',red_egb)
hold on
plot(1:10,lsDecLag,'-.','Color',red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Labor share')
yticks([0.5 1 1.5 2])
axis([1 10 0.25 2])
legend('Model','Data','Data (lagged)','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDecLag.eps','epsc');

plot(1:10,lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,lsDecCm,'-.','Color',0.15*[1 1 1] + 0.85*blue_egb)
hold on
plot(1:10,lsDecBm,'-d','Color',0.30*[1 1 1] + 0.7*blue_egb)
hold on
plot(1:10,lsDecEV,'--','Color',0.45*[1 1 1] + 0.55*blue_egb)
hold on
plot(1:10,lsDecData,'-','Color',red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Labor share')
yticks([0.5 1 1.5 2])
axis([1 10 0.25 2])
legend('Baseline model','Coles-Mortensen','Burdett-Mortensen','Endogenous-$\lambda$ extension','Data','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDecBench.eps','epsc');

plot(1:10,lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,lsDecPareto,'-.','Color',0.15*[1 1 1] + 0.85*blue_egb)
hold on
plot(1:10,lsDecData,'-','Color',red_egb)
hold on
plot(1:10,(1-alpha)*ones(10,1),'--','Color',[0.5 0.5 0.5])
xlabel('Labor productivity decile')
ylabel('Labor share')
axis([1 10 0 3])
legend('Baseline model (Gamma)','Baseline model (Pareto)','Data','$1-\alpha$','Location','Northeast')
grid on
hold off
saveas(gca,'..\Figures\lsDecPareto.eps','epsc');

plot(1:10,1-alpha-lsDec,'-o','Color',blue_egb)
hold on
plot(1:10,1-lsDecData-R*1.1*kRelDecData./lpRelDecData,'-','Color',red_egb)
hold on
plot(1:10,1-lsDecData-(R+0.1)*1.1*kRelDecData./lpRelDecData,'--','Color',0.3*[1 1 1] + 0.7*red_egb)
hold on
plot(1:10,1-lsDecData-(R-0.1)*1.1*kRelDecData./lpRelDecData,'-.','Color',0.6*[1 1 1] + 0.4*red_egb)
xlabel('Labor productivity decile')
ylabel('Profit share')
axis([1 10 -1.5 0.5])
legend('Model','Data (R=0.21)','Data (R=0.31)','Data (R=0.11)','Location','Southeast')
grid on
hold off
saveas(gca,'..\Figures\pShareDec.eps','epsc');
