function [lsAggBm lsAvgBm opCovBm yShareDecBm nShareDecBm lsDecBm lp9010Bm yBm uBm] = getBmModelOutput(zGrid0,Nz0,Gamma0zbar,u,eta,distributionType)
global r R alpha

% Burdett-Mortensen parameters
zbar = getGammaquant(Gamma0zbar,eta,0,distributionType);
zGrid = zGrid0(zGrid0>=Gamma0zbar);
cons = (alpha/R)^(1/(1-alpha));
bBm = (1-alpha)*(cons^alpha)*zbar.^(1/(1-alpha));
deltaBM = 0.0469;
lambdaBM = deltaBM*(1-u)/u;

% Equilibrium functions
uBm = deltaBM/(deltaBM+lambdaBM);
GammaFunc = @(z) getGammacdf(z,eta,zbar,distributionType);
gammaFunc = @(z) getGammapdf(z,eta,zbar,distributionType);
lpFunc = @(z) (cons^alpha)*z.^(1/(1-alpha));
lpFuncDiff = @(z) (cons^alpha)/(1-alpha)*z.^(1/(1-alpha)-1);
nFunc = @(z) (z>=zbar).*(lambdaBM*deltaBM)./( ( deltaBM + lambdaBM*(1-GammaFunc(z)) ).^2 );
phiFunc = @(z) (z>=zbar).*(lambdaBM*deltaBM)./( ( r+deltaBM + lambdaBM*(1-GammaFunc(z)) ).*( deltaBM + lambdaBM*(1-GammaFunc(z)) ) );
wFunc = @(z) (z>=zbar).*(1-alpha)*( lpFunc(z) - integral( @(x) lpFuncDiff(x).*phiFunc(x),zbar,z)./phiFunc(z) );

% Policy functions over grid
lpGridBm = lpFunc(zGrid);
wGridBm = zeros(1,length(zGrid));
for i=1:length(zGrid)
    wGridBm(i) = wFunc(zGrid(i));
end
wGridBm(isnan(wGridBm))=0;
lsGridBm = wGridBm./lpGridBm;
nGridBm=nFunc(zGrid);
gammaGrid = getGammapdf(zGrid,eta,zbar,distributionType);
gammaGridInt = [ 0.5*(zGrid(2)-zGrid(1))*gammaGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*gammaGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*gammaGrid(end) ];

% National Accounts
wNBm = (1-uBm)*(wGridBm.*nGridBm)*gammaGridInt';
yBm = (1-uBm)*(lpGridBm.*nGridBm)*gammaGridInt';
lsAggBm = wNBm/yBm;
lsAvgBm = gammaGridInt*lsGridBm';
opCovBm = lsAggBm-lsAvgBm;

% Productivity thresholds
qReq = [0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1];
zThresh = getGammaquant(qReq,eta,zbar,distributionType);
zThresh(1)=zGrid(1);
zThresh(end)=zGrid(end);

% Productivity dispersion
lpQ = (cons^alpha)*zThresh.^(1/(1-alpha));
lp9010Bm = log(lpQ(10)/lpQ(2));

% Initialize vectors
lpDec = zeros(10,1);
wDec = zeros(10,1);
nShareDec = zeros(10,1);

% Compute statistics by decile
NzDec = 200;
for d=1:10
    zGridDec = linspace(zThresh(d),zThresh(d+1),NzDec);
    
    gammaGridDec = getGammapdf(zGridDec,eta,zbar,distributionType);
    gammaIntDec = [ 0.5*(zGridDec(2)-zGridDec(1))*gammaGridDec(1) 0.5*(zGridDec(3:end)-zGridDec(1:end-2)).*gammaGridDec(2:end-1) 0.5*(zGridDec(end)-zGridDec(end-1))*gammaGridDec(end) ];
    gammaIntDec = gammaIntDec/sum(gammaIntDec);
    pGridDec = getGammapdf(zGridDec,eta,zbar,distributionType).*nFunc(zGridDec);
    pIntDec = [ 0.5*(zGridDec(2)-zGridDec(1))*pGridDec(1) 0.5*(zGridDec(3:end)-zGridDec(1:end-2)).*pGridDec(2:end-1) 0.5*(zGridDec(end)-zGridDec(end-1))*pGridDec(end) ];
    pIntDec = pIntDec/sum(pIntDec);
    
    nGridDec = nFunc(zGridDec);
    lpGridDec = (cons^alpha)*zGridDec.^(1/(1-alpha))';
    wGridDec = interp1(zGrid,wGridBm,zGridDec)';
    
    lpDec(d) = pIntDec*lpGridDec;
    wDec(d) = pIntDec*wGridDec;
    nShareDec(d) = gammaIntDec*nGridDec';
end

yShareDecBm = (nShareDec.*lpDec)/sum(nShareDec.*lpDec);
nShareDecBm = nShareDec/sum(nShareDec);
lsDecBm = wDec./lpDec;

end
