function [nGrid nGridNorm sizePmf sizeCdf zeta betayls betanls] = getDistN(lambda,chi,mu,eta,b,delta,distributionType)
global alpha R

% Grid for z
Nz0=100;
zGrid0 = real(getGrid(1,1/2,10,Nz0,2,1)); % affine-exponential

% Solve model
[zbar wbar zGrid vGrid wGrid] = getEQ(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,distributionType);
cons = (alpha/R)^(1/(1-alpha));
yGrid = (cons^alpha)*zGrid.^(1/(1-alpha));

%% Step 1 - Compute pareto exponent %%

% Rates
initialSize = 1.5;
Gamma0zbar = getGammacdf(zbar,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar)/initialSize;
u = getUnemp(lambda,chiX,muE,delta);

% Evaluate functions over grid
PGrid = getPcdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
pGrid = getPpdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
gammaGrid = getGammapdf(zGrid,eta,zbar,distributionType);
pGridInt = [ 0.5*(zGrid(2)-zGrid(1))*pGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*pGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*pGrid(end) ];
gammaGridInt = [ 0.5*(zGrid(2)-zGrid(1))*gammaGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*gammaGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*gammaGrid(end) ];
gammaGridInt = gammaGridInt/sum(gammaGridInt);
gGrid = lambda*u + lambda*(1-u)*PGrid - lambda*(1-u)*(1-PGrid)-delta;
Nz = length(zGrid);

% Compute exponent
Delta = 1/52;
Pi = (1-Delta*chiS)*speye(Nz) + Delta*chiS*repmat(gammaGridInt,[Nz 1]);
D = sparse(diag(exp(Delta*gGrid)));
spectralRad = @(s) max(abs(eig(Pi*(D.^s))))-1/(1-Delta*chiX);
zeta = fzero(spectralRad,[1e-32 5]);


%% Step 2 - Construct size Grid %%
Nn = 100;
nGrid = getGrid(1,1/4,1e9,Nn,2,distributionType); % affine-exponential

%% Step 3 - Construct Nnext grid %%

Nnext = zeros(Nz,Nn);
for z=1:Nz
    for n=1:Nn
        Nnext(z,n) = nGrid(n)*(1+Delta*gGrid(z));
    end
end

%% Step 4 - Computing distribution %%

stationaryDistribution = getxDist(Pi,Delta*chiX,nGrid,initialSize,Nnext,zeta,1+Delta*gGrid');

varphi = stationaryDistribution;
varphi = varphi/sum(varphi);
varphi = reshape(varphi,[Nn Nz]);
sizePmf = sum(varphi,2);
sizeCdf = cumsum(sizePmf);

F = u*muE/chiX;
nBar = (1-u)/F;
nGridNorm = nGrid/nBar;

%loglog(nGrid,1-sizeCdf)

%% Step 5 - Computing moments %%
wMat = repmat(wGrid,[Nn 1]);
nMat = repmat(nGrid',[1 Nz]);
yMat = repmat(yGrid,[Nn 1]);
gMat = repmat(gGrid,[Nn 1]);

LSavg = sum(sum(varphi.*wMat./yMat));
LSagg = sum(sum(nMat.*varphi.*wMat))/sum(sum(nMat.*varphi.*yMat));

logwMat = log(wMat);
logyMat = log(yMat);
loglsMat = logwMat-logyMat;

lognMat = log(nMat);
lognMat(nMat==0)=0;

logYMat = logyMat+lognMat;

logwMean = sum(sum(logwMat.*varphi));
logyMean = sum(sum(logyMat.*varphi));
logYMean = sum(sum(logYMat.*varphi));
loglsMean = sum(sum(loglsMat.*varphi));
lognMean = sum(sum(lognMat.*varphi));
gMean = sum(sum(gMat.*varphi));

logwVar = sum(sum(logwMat.^2.*varphi))-logwMean^2;
logyVar = sum(sum(logyMat.^2.*varphi))-logyMean^2;
logYVar = sum(sum(logYMat.^2.*varphi))-logYMean^2;
loglsVar = sum(sum(loglsMat.^2.*varphi))-loglsMean^2;
lognVar = sum(sum(lognMat.^2.*varphi))-lognMean^2;

logYlsCovar = sum(sum(logYMat.*loglsMat.*varphi))-logYMean*loglsMean;
logylsCovar = sum(sum(logyMat.*loglsMat.*varphi))-logyMean*loglsMean;
lognlsCovar = sum(sum(lognMat.*loglsMat.*varphi))-lognMean*loglsMean;
logwgCovar = sum(sum(logwMat.*gMat.*varphi)) - logwMean*gMean;

betaYls = logYlsCovar/logYVar;
betayls = logylsCovar/logyVar;
betanls = lognlsCovar/lognVar;
betaglogw = logwgCovar/logwVar;

% surf(nMat,yMat,varphi)
% xlim([0 5])
% ylim([0 5])



end

