function [zbar wbar zGrid vGrid wGrid] = getEQ(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,distributionType)
% solve the model for a set of parameters
global r R alpha

% Tolerance, maximum iterations, gain parameter
errTol = 1e-3;
iterMax = 25;

% Initialize
%zbarOld = 0.45;
zbarOld = 3;
wbarOld = b;
zbarVec = zeros(1,iterMax)*NaN;
wbarVec = zeros(1,iterMax)*NaN;

% Iterate over zbar (implicit method)
for i=1:iterMax
    % Update zbar
    [zbarNew vNew wNew] = getZbar(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,zbarOld,wbarOld,distributionType);
    if distributionType==2
        zbarNew = max(zbarNew,1-1/eta);
    end
    zbarVec(i) = zbarNew;
    
    % Update wbar
    [wbarNew VNew] = getWbar(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,zbarNew,wbarOld,wNew,distributionType);
    wbarVec(i) = wbarNew;
    
    % Stopping rules
    if i>2 & abs(zbarVec(i)-zbarVec(i-1))<errTol & abs(wbarVec(i)-wbarVec(i-1))<errTol
        disp('Converged.')
        break
    end
    if i==iterMax
        disp('Ended without convergence.')
        break
    end

% Generate initial values
zbarOld = zbarNew;
wOld = wNew;
wbarOld = wbarNew;
end


% Output
zbar = zbarNew;
wbar = wbarNew;
vGrid = vNew'; 
wGrid = wNew';
wGrid = wGrid(zGrid0>=zbar);
vGrid = vGrid(zGrid0>=zbar);
zGrid = zGrid0(zGrid0>=zbar);

end

