function [zbar wbar zGrid u lpGrid vGrid wGrid PGrid pGrid QGrid qGrid lambdaGrid Lambda gGrid hGrid sGrid] = getEQEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,distributionType)
% solve the model for a set of parameters
global r R alpha

% Tolerance, maximum iterations, gain parameter
errTol = 1e-3;
iterMax = 100;

% Initialize
zbarOld = 1;
wbarOld = bEV;
vGridOld = zGrid0'.^0;
PGridOld = getGammacdf(zGrid0,etaEV,zbarOld,1);
uOld = 0.07;
zbarVec = zeros(1,iterMax)*NaN;
wbarVec = zeros(1,iterMax)*NaN;

% Iterate over zbar (implicit method)
for i=1:iterMax
    
    % Update u,P,lambda
    [uNew PGridNew QGridNew lambdaGridNew LambdaNew] =  getupEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,zbarOld,vGridOld,PGridOld,uOld);
    
    % Update zbar
    [zbarNew vGridNew wGridNew] = getZbarEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,zbarOld,wbarOld,lambdaGridNew,PGridNew,QGridNew,uOld);
    zbarVec(i) = zbarNew;

    % Update wbar
    qGridNew = gradient(QGridNew)./gradient(zGrid0);
    [wbarNew VGridNew] = getWbarEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,lambdaBarEV,zbarNew,wbarOld,wGridNew,uNew,qGridNew,QGridNew,LambdaNew,distributionType);
    wbarVec(i) = wbarNew;

    % Stopping rules
    if i>2 & abs(zbarVec(i)-zbarVec(i-1))<errTol & abs(wbarVec(i)-wbarVec(i-1))<errTol & max(abs(vGridNew-vGridOld))<errTol
        disp('Converged.')
        break
    end
    if i==iterMax
        disp('Ended without convergence.')
        break
    end

% Generate initial values
zbarOld = zbarNew;
wbarOld = wbarNew;
vGridOld = vGridNew;
PGridOld = PGridNew;
uOld = uNew;

end

% Output
u=uNew;
Lambda = LambdaNew;
zbar = zbarNew;
wbar = wbarNew;
vGrid = vGridNew'; 
wGrid = wGridNew';
zGrid = zGrid0(zGrid0>=zbar);
wGrid = wGrid(zGrid0>=zbar);
vGrid = vGrid(zGrid0>=zbar);

lambdaGrid = lambdaGridNew(zGrid0>=zbar);
PGrid = PGridNew(zGrid0>=zbar);
pGrid = gradient(PGrid)./gradient(zGrid);
QGrid = cumtrapz(zGrid,lambdaGrid.*pGrid)/Lambda;
qGrid = gradient(QGrid)./gradient(zGrid);

hGrid = lambdaGrid*u + lambdaGrid*(1-u).*PGrid;
sGrid = Lambda*(1-u)*(1-QGrid) + deltaEV;
gGrid = hGrid-sGrid;

cons = (alpha/R)^(1/(1-alpha));
lpGrid = (cons^alpha)*zGrid.^(1/(1-alpha)) - (1/((1+thetaEV)*(1-alpha)))*lambdaBarEV*(u+(1-u)*PGrid).^(1+1/thetaEV).*vGrid;

end

