function [lsAgg lsAvg opCov u JDC JDD JCC JCB JC JD JR JRC JRBD rho lp9010 passthroughOLS varlogwEmp DHFslope] = getEVModelOutput(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,distributionType)
global r R alpha

% Solve baseline model
[zbar wbar zGrid u lpGrid vGrid wGrid PGrid pGrid QGrid qGrid lambdaGrid Lambda gGrid hGrid sGrid] = getEQEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,distributionType);

% Rates
Gamma0zbar = getGammacdf(zbar,etaEV,0,distributionType);
chiX = chiEV*Gamma0zbar;
chiS = chiEV*(1-Gamma0zbar);
muE = muEV*(1-Gamma0zbar);

% Evaluate functions over grid
gammaGrid = getGammapdf(zGrid,etaEV,zbar,distributionType);
gammaGridInt = [ 0.5*(zGrid(2)-zGrid(1))*gammaGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*gammaGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*gammaGrid(end) ];
pGridInt = [ 0.5*(zGrid(2)-zGrid(1))*pGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*pGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*pGrid(end) ];
lsGrid = wGrid./lpGrid;

% National Accounting
wN = (1-u)*trapz(zGrid,wGrid.*pGrid);
Y = (1-u)*trapz(zGrid,lpGrid.*pGrid);
lsAgg = wN/Y;
lsAvg = trapz(zGrid,(wGrid./lpGrid).*gammaGrid);
opCov = lsAgg-lsAvg;

% Job flows
JDD = exp(chiX)-1;
JDC = exp(-pGridInt(gGrid<0)*(gGrid(gGrid<0)'))-1;
JCC = exp(pGridInt(gGrid>0)*(gGrid(gGrid>0)'))-1;
JCB = exp(u*muE/(1-u))-1;
JD = JDC+JDD;
JC = JCC+JCB;
JR = (JC+JD)/2;
JRC = (JCC+JDC)/2;
JRBD = (JCB+JDD)/2;

% Productivity dispersion
qReq = [0.1 0.5 0.9 0.95];
zQ = getGammaquant(qReq,etaEV,zbar,distributionType);
lpQ = interpn(zGrid,lpGrid,zQ);
lp9590 = log(lpQ(4)/lpQ(3));
lp9050 = log(lpQ(3)/lpQ(2));
lp5010 = log(lpQ(2)/lpQ(1));
lp9010 = log(lpQ(3)/lpQ(1));

% productivity persistence
rho = exp(-chiS);

% OLS pass-through (emp-weighted)
logwGrid = log(wGrid);
loglpGrid = log(abs(lpGrid));
meanlogw = logwGrid*pGridInt';
meanloglp = loglpGrid*pGridInt';
varlogw = (logwGrid - meanlogw).^2*pGridInt';
varlp = (loglpGrid- meanloglp).^2*pGridInt';
covwlp = ((logwGrid-meanlogw).*(loglpGrid-meanloglp))*pGridInt';
passthroughOLS = covwlp/varlp;
varlogwEmp = varlogw;

% DHF regression
loghGrid = log(hGrid);
logvfGrid = log(u+(1-u)*PGrid);
meanlogh = loghGrid*gammaGridInt';
meanlogvf = logvfGrid*gammaGridInt';
varlogh = (loghGrid-meanlogh).^2*gammaGridInt';
covloghlogvf = ((loghGrid-meanlogh).*(logvfGrid-meanlogvf))*gammaGridInt';
DHFslope = covloghlogvf/varlogh;


end
