function [lsAgg lsAvg opCov u JDC JDD JCC JCB JC JD JR JRC JRBD rho lp9590 lp9050 lp5010 lp9010] = getModelOutputAgg(lambda,chi,mu,eta,b,delta,zbar,zGrid,vGrid,wGrid,distributionType)
global r R alpha

% Rates
Gamma0zbar = getGammacdf(zbar,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar);
u = getUnemp(lambda,chiX,muE,delta);

% Evaluate functions over grid
PGrid = getPcdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
pGrid = getPpdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
gammaGrid = getGammapdf(zGrid,eta,zbar,distributionType);
pGridInt = [ 0.5*(zGrid(2)-zGrid(1))*pGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*pGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*pGrid(end) ];
gammaGridInt = [ 0.5*(zGrid(2)-zGrid(1))*gammaGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*gammaGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*gammaGrid(end) ];
gGrid = lambda*u + lambda*(1-u)*PGrid - lambda*(1-u)*(1-PGrid)-delta;
cons = (alpha/R)^(1/(1-alpha));
lpGrid = (cons^alpha)*zGrid.^(1/(1-alpha));
lsGrid = wGrid./lpGrid;
kGrid = cons*zGrid.^(1/(1-alpha));

% National Accounts
wN = (1-u)*trapz(zGrid,wGrid.*pGrid);
Y = (1-u)*trapz(zGrid,lpGrid.*pGrid);
lsAgg = wN/Y;
lsAvg = gammaGridInt*lsGrid';
opCov = lsAgg-lsAvg;

% (r*(pGridInt*vGrid'))/(pGridInt*lpGrid')
% 1-alpha-lsAgg

% Job flows
P0 = ( lambda*(1-u)+delta-lambda*u )/(2*lambda*(1-u));
JDC = exp(-P0*(lambda*u-lambda*(1-u)-delta) - lambda*(1-u)*P0^2)-1;
JCC = exp((1-P0)*(lambda*u-lambda*(1-u)-delta) + lambda*(1-u)*(1-P0^2))-1;
% JDC = -pGridInt(gGrid<0)*(gGrid(gGrid<0)');
% JCC = pGridInt(gGrid>0)*(gGrid(gGrid>0)');
JDD = exp(chiX)-1;
JCB = exp(u*muE/(1-u))-1;
JD = JDC+JDD;
JC = JCC+JCB;
JR = (JC+JD)/2;
JRC = (JCC+JDC)/2;
JRBD = (JCB+JDD)/2;

% Productivity dispersion
qReq = [0.1 0.5 0.9 0.95];
zQ = getGammaquant(qReq,eta,zbar,distributionType);
lpQ = (cons^alpha)*zQ.^(1/(1-alpha));
lp9590 = log(lpQ(4)/lpQ(3));
lp9050 = log(lpQ(3)/lpQ(2));
lp5010 = log(lpQ(2)/lpQ(1));
lp9010 = log(lpQ(3)/lpQ(1));

% productivity persistence
rho = exp(-chiS);

% OLS pass-through (emp-weighted)
logwGrid = log(wGrid);
loglpGrid = log(lpGrid);
meanlogw = logwGrid*pGridInt';
meanloglp = loglpGrid*pGridInt';
varlogw = (logwGrid - meanlogw).^2*pGridInt';
varlp = (loglpGrid- meanloglp).^2*pGridInt';
covwlp = ((logwGrid-meanlogw).*(loglpGrid-meanloglp))*pGridInt';
passthroughOLS = covwlp/varlp;


end

