function [nShareDec yShareDec wRelDec lpRelDec lsDec] = getModelOutputByDecile(lambda,chi,mu,eta,b,delta,zbar,zGrid,vGrid,wGrid,distributionType)
global r R alpha

% Rates
Gamma0zbar = getGammacdf(zbar,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar);
u = getUnemp(lambda,chiX,muE,delta);

% Evaluate functions over grid
PGrid = getPcdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
pGrid = getPpdf(zGrid,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
gammaGrid = getGammapdf(zGrid,eta,zbar,distributionType);
pGridInt = [ 0.5*(zGrid(2)-zGrid(1))*pGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*pGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*pGrid(end) ];
gammaGridInt = [ 0.5*(zGrid(2)-zGrid(1))*gammaGrid(1) 0.5*(zGrid(3:end)-zGrid(1:end-2)).*gammaGrid(2:end-1) 0.5*(zGrid(end)-zGrid(end-1))*gammaGrid(end) ];
gGrid = lambda*u + lambda*(1-u)*PGrid - lambda*(1-u)*(1-PGrid)-delta;
cons = (alpha/R)^(1/(1-alpha));
lpGrid = (cons^alpha)*zGrid.^(1/(1-alpha));
lsGrid = wGrid./lpGrid;
kGrid = cons*zGrid.^(1/(1-alpha));

% Productivity thresholds
qReq = [0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1];
zThresh = getGammaquant(qReq,eta,zbar,distributionType);
zThresh(1)=zGrid(1);
zThresh(end)=zGrid(end);

% Initialize vectors
gDec = zeros(10,1);
lpDec = zeros(10,1);
wDec = zeros(10,1);
nShareDec = zeros(10,1);

% Compute statistics by decile
NzDec = 200;
for d=1:10
    zGridDec = linspace(zThresh(d),zThresh(d+1),NzDec);
    
    gammaGridDec = getGammapdf(zGridDec,eta,zbar,distributionType);
    gammaIntDec = [ 0.5*(zGridDec(2)-zGridDec(1))*gammaGridDec(1) 0.5*(zGridDec(3:end)-zGridDec(1:end-2)).*gammaGridDec(2:end-1) 0.5*(zGridDec(end)-zGridDec(end-1))*gammaGridDec(end) ];
    gammaIntDec = gammaIntDec/sum(gammaIntDec);
    pGridDec = getPpdf(zGridDec,zbar,lambda,chi,mu,eta,b,delta,u,distributionType);
    pIntDec = [ 0.5*(zGridDec(2)-zGridDec(1))*pGridDec(1) 0.5*(zGridDec(3:end)-zGridDec(1:end-2)).*pGridDec(2:end-1) 0.5*(zGridDec(end)-zGridDec(end-1))*pGridDec(end) ];
    pIntDec = pIntDec/sum(pIntDec);
    
    lpGridDec = (cons^alpha)*zGridDec.^(1/(1-alpha))';
    kGridDec = cons*zGridDec.^(1/(1-alpha))';
    gGridDec = interp1(zGrid,gGrid,zGridDec)';
    wGridDec = interp1(zGrid,wGrid,zGridDec)';
    
    gDec(d) = pIntDec*gGridDec;
    lpDec(d) = pIntDec*lpGridDec;
    wDec(d) = pIntDec*wGridDec;
    nShareDec(d) = getPcdf(zThresh(d+1),zbar,lambda,chi,mu,eta,b,delta,u,distributionType)-getPcdf(zThresh(d),zbar,lambda,chi,mu,eta,b,delta,u,distributionType);

end

yShareDec = (nShareDec.*lpDec)/sum(nShareDec.*lpDec);
nShareDec = nShareDec;
wRelDec = wDec./sum(wDec.*nShareDec);
wRelLpDec = wDec./sum(lpDec.*nShareDec);
lpRelDec = lpDec./sum(lpDec.*nShareDec);
lsDec = wDec./lpDec;


end

