function [wbarNew VNew] = getWbar(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,zbarOld,wbarOld,wOld,distributionType);
global r R alpha

% Rates
Gamma0zbar = getGammacdf(zbarOld,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar);

% Unemployment rate
u = getUnemp(lambda,chiX,muE,delta);

% Evaluate functions over grid
gamma0pdfGrid = getGammapdf(zGrid0,eta,0,distributionType);
gammapdfGrid = getGammapdf(zGrid0,eta,zbarOld,distributionType);
pGrid = getPpdf(zGrid0,zbarOld,lambda,chi,mu,eta,b,delta,u,distributionType);

% Integration against p operator (operator C)
CopRow = [ 0.5*(zGrid0(2)-zGrid0(1))*gammapdfGrid(1) 0.5*(zGrid0(3:end)-zGrid0(1:end-2)).*gammapdfGrid(2:end-1) 0.5*(zGrid0(end)-zGrid0(end-1))*gammapdfGrid(end) ];
Cop = repmat(CopRow,[Nz0 1]);

% Cumulative integration against p(z) (operator D)
nonzeroDop = Nz0*(Nz0+1)/2 - 1; % number of nonzero entries
Ivec = zeros(nonzeroDop, 1);
Jvec = zeros(nonzeroDop, 1);
Vvec = zeros(nonzeroDop, 1);
for j = 2:Nz0
    thisIdx = [(j*(j-1)/2)+1:j*(j+1)/2] - 1;
    Ivec(thisIdx) = j;
    Jvec(thisIdx) = 1:j;
    Vvec(thisIdx(1)) = 0.5*(zGrid0(2)-zGrid0(1))*pGrid(1);
    Vvec(thisIdx(2:j-1)) = 0.5*(zGrid0(3:j)-zGrid0(1:j-2)).*pGrid(2:j-1);
    Vvec(thisIdx(j)) = 0.5*(zGrid0(end)-zGrid0(end-1))*pGrid(end);
end
Dop = sparse(Ivec,Jvec,Vvec,Nz0,Nz0);

% Integration against gamma0 operator (operator E)
PbarGrid = 1-getPcdf(zGrid0,zbarOld,lambda,chi,mu,eta,b,delta,u,distributionType);
Eop = sparse(1:Nz0,1:Nz0,PbarGrid);

% Solve for V using the LCP representation
qVec = b-wOld;
Mop = (r+chi+delta)*speye(Nz0,Nz0)-(mu-chi)*Cop+lambda*(1-u)*(Dop+Eop);
VNew = LCP(Mop,qVec);

% Update wbar
wbarNew = b + (mu-chi)*CopRow*VNew;
%wbarNew = 0.01*wbarNew + 0.99*wbarOld;

end

