function [zbarNew vNew wNew] = getZbar(zGrid0,Nz0,lambda,chi,mu,eta,b,delta,zbarOld,wbarOld,distributionType)
% solve for zbar conditional on zbarOld and wbarOld
global r R alpha

% Rates
Gamma0zbar = getGammacdf(zbarOld,eta,0,distributionType);
chiX = chi*Gamma0zbar;
chiS = chi*(1-Gamma0zbar);
muE = mu*(1-Gamma0zbar);

% Unemployment rate
u = getUnemp(lambda,chiX,muE,delta);

% Evaluate functions over grid
gamma0pdfGrid = getGammapdf(zGrid0,eta,0,distributionType);
%gamma0pdfGrid = getGammapdf(zGrid0,eta,zbarOld,distributionType);
PGrid = getPcdf(zGrid0,zbarOld,lambda,chi,mu,eta,b,delta,u,distributionType);
gGrid = lambda*u + lambda*(1-u)*PGrid - lambda*(1-u)*(1-PGrid)-delta;
gDiffGrid = [(gGrid(2)-gGrid(1))/(zGrid0(2)-zGrid0(1)) (gGrid(3:end)-gGrid(1:end-2))./(zGrid0(3:end)-zGrid0(1:end-2))  (gGrid(end)-gGrid(end-1))/(zGrid0(end)-zGrid0(end-1))]; % central derivatives
cons = (alpha/R)^(1/(1-alpha));
lpGrid = (cons^alpha)*zGrid0.^(1/(1-alpha));

% Cumulative integration against g'(z) (operator A)
nonzeroAop = Nz0*(Nz0+1)/2 - 1; % number of nonzero entries
Ivec = zeros(nonzeroAop, 1);
Jvec = zeros(nonzeroAop, 1);
Vvec = zeros(nonzeroAop, 1);
for j = 2:Nz0
    thisIdx = [(j*(j-1)/2)+1:j*(j+1)/2] - 1;
    Ivec(thisIdx) = j;
    Jvec(thisIdx) = 1:j;
    Vvec(thisIdx(1)) = 0.5*(zGrid0(2)-zGrid0(1))*gDiffGrid(1);
    Vvec(thisIdx(2:j-1)) = 0.5*(zGrid0(3:j)-zGrid0(1:j-2)).*gDiffGrid(2:j-1);
    Vvec(thisIdx(j)) = 0.5*(zGrid0(end)-zGrid0(end-1))*gDiffGrid(end);
end
Aop = sparse(Ivec,Jvec,Vvec,Nz0,Nz0);

% Multiplication by g(z) (operator B)
Bop = sparse(1:Nz0,1:Nz0,gGrid);

% Integration against gamma0 operator (operator C)
CopRow = [ 0.5*(zGrid0(2)-zGrid0(1))*gamma0pdfGrid(1) 0.5*(zGrid0(3:end)-zGrid0(1:end-2)).*gamma0pdfGrid(2:end-1) 0.5*(zGrid0(end)-zGrid0(end-1))*gamma0pdfGrid(end) ];
Cop = repmat(CopRow,[Nz0 1]);

% Solve for v using the LCP representation
qVec = - (1-alpha)*lpGrid' + wbarOld;
Mop = (r+chi)*speye(Nz0,Nz0) + Aop - Bop - chi*Cop;
vNew = LCP(Mop,qVec);
wNew = wbarOld + Aop*vNew;

% linear extrapolation
zGuess = min(zGrid0(vNew>0));
vGuess = min(vNew(vNew>0));
gGuess = min(gGrid(vNew>0));
vPrimeGuess = (cons^alpha*zGuess.^(alpha/(1-alpha)))/(r+chi-gGuess);
adjustment = - vGuess/vPrimeGuess;
%adjustment = 0;
zbarNew = max(max([zGuess + adjustment 0]),min(zGrid0));

% Update zbar
zbarNew = zbarNew;
% zbarNew = 0.5*zbarNew + 0.5*zbarOld;

end

