function [zbarNew vNew wNew] = getZbarEV(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,zbar,wbar,lambdaGrid,PGrid,QGrid,u)
% solve for zbar conditional on zbarOld and wbarOld
global r R alpha

% Rates
Gamma0zbar = getGammacdf(zbar,etaEV,0,1);
chiX = chiEV*Gamma0zbar;
chiS = chiEV*(1-Gamma0zbar);
muE = muEV*(1-Gamma0zbar);

% Evaluate functions over grid
gamma0pdfGrid = getGammapdf(zGrid0,etaEV,0,1);
pGridOld = gradient(PGrid)./gradient(zGrid0);
Lambda = trapz(zGrid0,lambdaGrid.*pGridOld);
QGrid = cumtrapz(zGrid0,lambdaGrid.*pGridOld)/Lambda;

hGrid = lambdaGrid*u + lambdaGrid*(1-u).*PGrid;
sGrid = Lambda*(1-u)*(1-QGrid) + deltaEV;
gGrid = hGrid-sGrid;

pGrid = gradient(PGrid)./gradient(zGrid0);
gDiffGrid = 2*lambdaGrid*(1-u).*pGrid;

cvGrid = (1/(1+thetaEV))*lambdaBarEV*(u+(1-u)*PGrid).^(1+1/thetaEV);
cvhGrid = (1/(1+thetaEV))*lambdaBarEV*(u+(1-u)*PGrid).^(1/thetaEV)./lambdaGrid;

% Cumulative integration against g'(z) (operator A)
nonzeroAop = Nz0*(Nz0+1)/2 - 1; % number of nonzero entries
Ivec = zeros(nonzeroAop, 1);
Jvec = zeros(nonzeroAop, 1);
Vvec = zeros(nonzeroAop, 1);
for j = 2:Nz0
    thisIdx = [(j*(j-1)/2)+1:j*(j+1)/2] - 1;
    Ivec(thisIdx) = j;
    Jvec(thisIdx) = 1:j;
    Vvec(thisIdx(1)) = 0.5*(zGrid0(2)-zGrid0(1))*gDiffGrid(1);
    Vvec(thisIdx(2:j-1)) = 0.5*(zGrid0(3:j)-zGrid0(1:j-2)).*gDiffGrid(2:j-1);
    Vvec(thisIdx(j)) = 0.5*(zGrid0(end)-zGrid0(end-1))*gDiffGrid(end);
end
Aop = sparse(Ivec,Jvec,Vvec,Nz0,Nz0);

% Multiplication by g(z)-c(z)/v(z) (operator B)
Bop = sparse(1:Nz0,1:Nz0,hGrid-sGrid-cvGrid);

% Integration against gamma0 operator (operator C)
CopRow = [ 0.5*(zGrid0(2)-zGrid0(1))*gamma0pdfGrid(1) 0.5*(zGrid0(3:end)-zGrid0(1:end-2)).*gamma0pdfGrid(2:end-1) 0.5*(zGrid0(end)-zGrid0(end-1))*gamma0pdfGrid(end) ];
Cop = repmat(CopRow,[Nz0 1]);

% Solve for v using the LCP representation
cons = (alpha/R)^(1/(1-alpha));
qVec = - (1-alpha)*(cons^alpha)*zGrid0.^(1/(1-alpha))' + wbar;
Mop = (r+chiEV)*speye(Nz0,Nz0) + Aop - Bop - chiEV*Cop;
vNew = LCP(Mop,qVec);
wNew = wbar + Aop*vNew;

% linear extrapolation
zGuess = min(zGrid0(vNew>0));
vGuess = min(vNew(vNew>0));
gGuess = min(gGrid(vNew>0));
vPrimeGuess = (cons^alpha*zGuess.^(alpha/(1-alpha)))/(r+chiEV-gGuess);
adjustment = - vGuess/vPrimeGuess;
adjustment = 0;
zbarNew = max([zGuess + adjustment 0]);

% Update zbar
zbarNew = zbarNew;
%zbarNew = 0.01*zbarNew + 0.99*zbarOld;

end

