function [u PGrid QGrid lambdaGrid Lambda] = getUP_EVext(zGrid0,Nz0,chiEV,muEV,etaEV,bEV,deltaEV,thetaEV,lambdaBarEV,zbarOld,vGridOld,PGridOld,uOld)

% Update u, P, lambda until convergence
global r R alpha

% Inputs
GammaGrid = getGammacdf(zGrid0,etaEV,zbarOld,1);
Gamma0zbar = getGammacdf(zbarOld,etaEV,0,1);
chiX = chiEV*Gamma0zbar;
chiS = chiEV*(1-Gamma0zbar);
muE = muEV*(1-Gamma0zbar);

% Initial guesses
lambdaGrid = lambdaBarEV*(uOld + (1-uOld)*PGridOld).^(1/thetaEV);
pGridOld = gradient(PGridOld)./gradient(zGrid0);
LambdaOld = trapz(zGrid0,lambdaGrid.*pGridOld);
QGridOld = cumtrapz(zGrid0,lambdaGrid.*pGridOld)/LambdaOld;

% Technical parameters
DeltaUpdate = 1/12;
iterMax = 1e5;

% Update
for i=1:iterMax
    uNew = uOld + DeltaUpdate*( (deltaEV+chiX)*(1-uOld) - uOld*(muE+LambdaOld*(1-uOld)));
    PGridNew = PGridOld + DeltaUpdate*( (1-uNew)*LambdaOld*PGridOld.*(QGridOld-1) + (uNew/(1-uNew))*muE*GammaGrid + uNew*LambdaOld*QGridOld - (deltaEV+chiX)*PGridOld + chiS*(GammaGrid-PGridOld) );
    pGridNew = gradient(PGridNew)./gradient(zGrid0);
    lambdaGridNew = lambdaBarEV*(uNew + (1-uNew)*PGridNew).^(1/thetaEV);
    LambdaNew = trapz(zGrid0,lambdaGrid.*pGridNew);
    QGridNew = cumtrapz(zGrid0,lambdaGrid.*pGridNew)/LambdaNew;
   
    %gGrid = lambdaGridNew.*(uNew + (1-uNew)*PGridNew) - (1-uNew)*LambdaNew*(1-QGridNew) - delta;
    %LambdaNew-chi-delta<0
    gain = max([abs(PGridNew-PGridOld) abs(uNew-uOld)]);
    
    if gain<1e-7
        %disp('u and P updated succesfully')
        break
    end
    
        
    if i==iterMax
        disp('u and P updated without convergence')
        break
    end
    
    
    uOld=uNew;
    PGridOld=PGridNew;
    pGridOld=pGridNew;
    lambdaGridOld=lambdaGridNew;
    LambdaOld=LambdaNew;
    QGridOld=QGridNew;
end

u=uNew;
PGrid=PGridNew;
QGrid=QGridNew;
lambdaGrid=lambdaGridNew;
Lambda=LambdaNew;

QGridanalytical = (u+(1-u)*PGrid).^(1+1/thetaEV)-u^(1+1/thetaEV)/(1-u^(1+1/thetaEV));

if max(abs(QGridanalytical-QGrid))>1e3
    disp('Qgrid is not accurate')
end

end

